<?php
/*
Plugin Name: DB Cache
Description: Add transient cache helper
Version: 0.1
*/

namespace Classes\Bwap;

class DBCache
{
    /**
     * Add data to transient cache or return if it is still valid
     *
     * @param  $transient_key  the key used to store the transient
     * @param  $duration  the duration to wait before invalidating the transient
     * @param  $user_function  the function to run if no transient is found
     * @param  $assoc  boolean indicating if you want to get and array or an object
     *
     * @return  mixed  the value of the transient or the value of the user function
     */
    public static function getOrSet($transient_key, $duration, $user_function, $assoc = true, $publimmoClient) {
        $transient = get_transient($transient_key);

        // if there is still cache, return the results
        if ($transient !== false) {
            $transient = json_decode($transient, $assoc);
            if ($assoc) {
                return array_values($transient);
            } else {
                return $transient;
            }
        }

        // cache the results
        $user_data = $user_function($publimmoClient);

        // check if the user data can be saved as a string
        if (is_array($user_data) || is_object($user_data)) {
            $json_user_data = json_encode($user_data);
        }

        set_transient($transient_key, $json_user_data, $duration);
        return $user_data;
    }
}

