<?php
/**
 * ObjetsSearchEngine allows to prepare query and fetch results from the webservice
 *
 * @package Publimmo
 * @subpackage Helpers
 */

namespace Classes\PublimmoPro;

class ObjetsSearchEngine{
    private $SearchType = '';
    private $forceFetchingAllObjects = false;
    public $results = array();
    public $resultsNumber;
    private $choose = '';
    private $id_courtier = '';
    private $mot_cle = '';
    private $listPhotos = '';
    /** @var Client */
    private $client;

    public function __construct($client, $searchType, $forceFetchingAllObjects = false, $choose = "", $id_du_courtier = "", $mot_cle = "", $listPhotos = ""){
        if(!in_array($searchType, array('any', 'acheter', 'louer', 'promotions'))){
            trigger_error('Search type must be one of any acheter louer or promotions. '.$searchType.' given.', E_USER_ERROR);
            return false;
        }
        $this->themeVersion = wp_get_theme()->template;
        $this->SearchType = $searchType;
        $this->forceFetchingAllObjects = $forceFetchingAllObjects;
        $this->choose = $choose;
        $this->id_courtier = $id_du_courtier;
        $this->mot_cle = $mot_cle;
        $this->listPhotos = $listPhotos;
        $this->client = $client;
        $this->results = $this->searchObjects();
        if($this->client->getKey()){
            echo $this->getObjectsCoordinatesForJS();
        }
        return $this;
    }

    private function buildQueryString(){

        $params = array(
            'key' => $this->client->getKey(),
            'ul' => ICL_LANGUAGE_CODE,
            't' => '', //Transaction
            'p' => '', // Promotions
        );
        if($this->SearchType == "acheter"){
            $params['t'] = 1;
        }elseif($this->SearchType == "louer"){
            $params['t'] = 2;
        }elseif(isset($_GET['t'])){
            $params['t'] = $_GET['t'];
        }elseif($this->SearchType == "promotions"){
            $params['p'] = 2;
        }elseif(isset($_GET['p'])){
            $params['p'] = $_GET['p'];
        }else{
            $params['p'] = 0;
        }

        if($this->forceFetchingAllObjects == false){
            $searchParams = array(
                'type_1' => '',
                'type_2' => '',
                'type_3' => '',
                'type_4' => '',
                'type_5' => '',
                'type_6' => '',
                'sousType' => '',
                'prixMin' => '',
                'prixMax' => '',
                'surfaceMin' => '',
                'surfaceMax' => '',
                'pieceMin' => '',
                'pieceMax' => '',
                'region' => '',
                'commune' => '',
                'dist' => '',
                'ns' => '',
                'tri' => '',
                'triSens' => '',
                'id' => '',
                'promotionId' => '',
                'pays' => '',
                'locationType' => '',
                'loc' => '',
                'ids' => '',
                'courtierId' => '',
                'selfOnly' => get_option('selfonly', 'non') == 'non' ? 0 : 1,
                'listPhotos' => "0",
                'extendedInfos' => 1
            );

            // TODO
            //$show_promotion = get_field("affichage_des_promotions");
            $show_promotion = "oui";
            //$show_promotion_on_promotion_page = get_field("afficher_la_liste_des_objets");
            $show_promotion_on_promotion_page = "choose";

            if(is_front_page() && $show_promotion == "latest"){
                $searchParams['selfOnly'] = 1;
            }

            if($this->SearchType == 'promotions' && get_option('selfonly_promotions', 'non') == 'oui'){
                $searchParams['selfOnly'] = 1;
            }

            if($show_promotion == "oui" || $show_promotion_on_promotion_page == "choose" || $this->choose != ""){
                if($this->choose != "" && $this->choose != 'fromlist'){
                    $searchParams['ids'] = $this->choose;
                    $searchParams['selfOnly'] = 0;
                }else{
                    if ($this->choose == 'fromlist' && $this->themeVersion == 'publimmo') {
                        $searchParams['ids'] = get_field("identifiants_des_objets_en_promotions");
                    }
                }
            }

            if(!empty($_GET['communeName'])) {
                if (is_int((int) $_GET['communeName'])) {
                    $npa = (int) $_GET['communeName'];
                } else {
                    list($npa, $commune) = explode(' ', $_GET['communeName']);
                }
                
                if (is_int((int) $npa)) {
                    $searchParams['npaOrder'] = $npa;
                }
            }

            if(isset($_GET['ns']) || $this->mot_cle){
                if($this->mot_cle){
                    $searchParams['ns'] = $this->mot_cle;
                }else{
                    $searchParams['ns'] = $_GET['ns']; 
                }
                $searchParams['selfOnly'] = 1;
            }

            if(isset($_GET['courtierId']) || $this->id_courtier){
                if($this->id_courtier){
                    $searchParams['courtierId'] = $this->id_courtier;
                }else{
                    $searchParams['courtierId'] = $_GET['courtierId'];
                }
            }

            $hasForeignersFeature = get_option('foreigners', 'inactive') == 'active';
            if ($hasForeignersFeature) {
                $searchParams['foreigners'] = $_GET['foreigners'] ?? 0;
            }

            $hasSecondHomeFeature = get_option('second_home', 'inactive') == 'active';
            if ($hasSecondHomeFeature) {
                $searchParams['residenceSecondaire'] = $_GET['residenceSecondaire'] ?? 0;
            }

            if($this->choose != ""){
                $searchParams['selfOnly'] = 0;
            }  

            if($this->listPhotos){
                $searchParams['listPhotos'] = $this->listPhotos;
            }

            // hydrate search params
            foreach($searchParams as $k => $v){
                if(isset($_GET[$k])){
                    $searchParams[$k] = $_GET[$k];
                }
            }

            // manage subtype
            if (strpos($searchParams['type_1'], '_')) {
                $types = explode('_', $searchParams['type_1']);
                $searchParams['type_1'] = $types[0];
                $searchParams['sousType'] = $types[1];
            }

            $params = array_merge($params, $searchParams);

            if(isset($_GET['loc'])){
                $locations = explode('|',$_GET['loc']);
                /*Search more than one location, might occur when clicking on a cluster*/
                if(count($locations)>1){
                    $return = array();
                    foreach ($locations as $loc){
                        $params['loc'] = trim($loc);
                        $query_string = http_build_query(array_filter($params, function ($value) {
                            return $value !== '';
                        }));
                        $return[] = $this->client->getApiUrl().'/objets?'.$query_string;
                    }
                    return $return;
                }else{
                    $params['loc'] = trim($_GET['loc']);
                }
            }
        }

        $query_string = http_build_query(array_filter($params, function ($value) {
            return $value !== '';
        }));

        return array($this->client->getApiUrl().'/objets?'.$query_string);
    }

    private function getObjectsCoordinatesForJS(){
        if ($this->resultsNumber <= 0 || isset($GLOBALS['addresses_are_already_sent'])) {
            return false;
        }

        $GLOBALS['addresses_are_already_sent'] = true;

        $addresses = [];

        foreach ($this->results as $o) {
            if (!isset($addresses[$o->localite])) {
                if (empty($o->latitude) || empty($o->longitude)) {
                    continue;
                }

                $addresses[$o->localite] = [
                    'lat'=>$o->latitude,
                    'lng'=>$o->longitude,
                    'nbObj'=>1,
                    'title'=>$o->localite
                ];
            }else{
                ++$addresses[$o->localite]['nbObj'];
            }
        }

        return '<script>var addresses = '.json_encode($addresses).'</script>';
    }

    private function searchObjects(){
        //Build the queries
        $query_strings = $this->buildQueryString();
        foreach($query_strings as $request){
            $json = json_decode($this->getContents($request));
            if($json !== null){
                $this->results = array_merge($this->results, $json->results);
            }
        }

        /*
        Exclude ids
         */
        $filter_type = get_option('filter_type');
        if($filter_type != 'disabled'){
            $objects_to_filter = get_option('objects_to_filter');
            $this->filterResults($filter_type, $objects_to_filter);
        }
        $this->resultsNumber = count($this->results);
        if($this->resultsNumber > 0){
            //Set the list of found results in SESSION in order to reuse it to navigate from Objet to Objet.
            $listid = wp_list_pluck($this->results, 'id');
            $this->setSearchParams($listid);
        }
        return $this->results;
    }

    private function getContents($url){
        $url = str_replace(' ','%20',$url);
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_HEADER, false);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
        curl_setopt($ch, CURLOPT_FOLLOWLOCATION, 0);
        $result = curl_exec($ch);

        curl_close($ch);
        return $result;
    }

    private function setSearchParams($listid){
        add_action('wp_footer', function () use ($listid) {
            global $wp;
            $url = add_query_arg($_SERVER['QUERY_STRING'], '', home_url($wp->request));
            ?>
            <script>
                var d = new Date();
                d.setTime(d.getTime() + (0.5*60*60*1000)); // 30mn
                var expires = "expires="+ d.toUTCString();
                document.cookie = "search_page=<?= $url ?>;path=/;"+expires;
                document.cookie = "search_list=<?= json_encode($listid) ?>;path=/;"+expires;;
            </script>
            <?php
        });
    }

    /**
     * Filter by including or excluding a list of object id
     *
     * @param  string $filter_type       include or exlcude
     * @param  string $objects_to_filter list of objects to filter
     *
     * @return mixed                    false or results
     */
    private function filterResults($filter_type, $objects_to_filter){
        if(empty($objects_to_filter)){
            return false;
        }
        //remove whitespaces, make an array and check if is numeric
        $objects_to_filter = preg_replace('/\s+/', '', $objects_to_filter);
        $objects_to_filter = explode(',', $objects_to_filter);
        $objects_to_filter = array_filter($objects_to_filter, 'is_numeric');

        if(count($objects_to_filter) <= 0){
            return false;
        }

        foreach ($this->results as $k => $pi_object){
            if($filter_type == 'include'){
                if(!in_array($pi_object->id, $objects_to_filter)){
                    unset($this->results[$k]);
                }
            }elseif($filter_type == 'exclude'){
                if(in_array($pi_object->id, $objects_to_filter)){
                    unset($this->results[$k]);
                }
            }
        }

        // resets the keys, otherwise, pagination is wrong
        $this->results = array_values($this->results);

        return $this->results;
    }

    public function sortBy($order)
    {
        if (empty($order)) {
            return false;
        }

        $lines = explode(PHP_EOL, $order);
        $lines = array_map('trim', $lines);
        $order = array_map(function($line) {
            list($field, $direction, $type) = explode(':', $line);
            return compact('field', 'direction', 'type');
        }, $lines);

        return usort($this->results, function ($a, $b) use ($order) {
            $t = array(true => -1, false => 1);
            $r = true;
            $k = 1;

            foreach ($order as $key => $rule) {
                $aVal = $a->{$rule['field']} ?? '';
                $bVal = $b->{$rule['field']} ?? '';

                if ($rule['type'] == 'integer') {
                    $aVal = filter_var(rtrim($aVal, '-'), FILTER_SANITIZE_NUMBER_INT);
                    $bVal = filter_var(rtrim($bVal, '-'), FILTER_SANITIZE_NUMBER_INT);
                }

                $k = ($rule['direction'] == 'asc') ? 1 : -1;
                $r = ($aVal < $bVal);

                if ($aVal !== $bVal) {
                    return $t[$r] * $k;
                }

            }

            return $t[$r] * $k;
        });
    }
}
