<?php
/**
 * This class manages technical Data received from an object
 *
 * @package Publimmo
 * @subpackage Helpers
 */

namespace Classes\PublimmoPro;

class TechnicalData
{
    /**
     * Technical data
     *
     * Each key of the table contains a subtable containing translations
     *
     * @var table
     */
    public static $data = [
        "acces_cff" => [ "Zugnähe", "Train access", "Accès CFF" ],
        "annee_constr" => [ "Baujahr", "Year built", "Année de construction" ],
        "annee_fin" => [ "Abgeschlossen Bau", "Completed construction", "Fin de la construction" ],
        "annee_renov" => [ "Jahr der Renovierung", "Last renovation", "Année de rénovation" ],
        "charges_mens" => [ "Monatliche Nebenkosten ", "Monthly maintenance charges", "Charges mensuelles" ],
        "cos" => [ "Index der Bebaubarkeit des Landes (COS)", "Coefficient of ground occupation (CGO)", "Indice d'occupation du sol (COS)" ],
        "cus" => [ "Index der Landnutzung (CUS)", "Coefficient of ground use of (CGO)", "Indice d'utilisation du sol (CUS)" ],
        "date_dispo" => [ "Verfügbarkeitsdatum", "Date of availability", "Date de disponibilité" ],
        "etage" => [ "Etage", "Floor", "Etage" ],
        "etage_type" => [ "Etagentyp", "Type of floor", "Type d'étage" ],
        // manque les traductions
        "etat" => [ "Etat" ],
        "location_type" => [ "Vermietung", "Rental", "Location" ],
        // manque les traductions
        "lot" => [ "Lot" ],
        "nb_boxes" => [ "Box", "Storage box", "Box(s)" ],
        "nb_chambres" => [ "Anzahl der Schlafzimmer", "Number of bedrooms", "Nombre de chambres" ],
        "nb_commerces" => [ "Geschäfte", "Facilities", "Commerces" ],
        "nb_garages" => [ "Garage(n)", "Garage(s)", "Garage(s)" ],
        "nb_logements" => [ "Wohnungen", "Housings", "Logements" ],
        "nb_parccouv" => [ "Dachten Aussen Park", "Covered outdoor park", "Parc(s) extérieur(s) couvert(s)" ],
        "nb_parcext" => [ "Parkplätze ausserhalb", "Outside parking spaces", "Parc(s) extérieur(s)" ],
        "nb_parcint" => [ "Innenpark", "Indoor parking", "Parc(s) intérieur(s)" ],
        "nb_pieces" => [ "Anzahl der Raüme", "Number of rooms", "Nombre de pièces" ],
        "nb_sallesdebain" => [ "Anzahl Badezimmer", "Number of bathrooms", "Nombre de salles de bain" ],
        "nb_vitrines" => [ "Schaufenster", "Window", "Vitrines" ],
        "no_reel" => [ "reelle Zahl", "real number", "No réel" ],
        "place_nombre" => [ "Anzahl der Plätze", "Number of places", "Nombre de place" ],
        // manque les traductions
        "prix_m2_an" => [ "" ],
        "rendement_brut" => [ "Gewinn brutto %", "Gross return", "Rendement brut  %" ],
        "rendement_net" => [ "Gewinn netto %", "Net return", "Rendement net %" ],
        "residence_secondaire" => [ "Zweitwohnung im Verkauf", "Sold as second residence", "Vente en résidence secondaire" ],
        "sanitaires_type" => [ "WC/Bad", "WC", "WC / Sanitaires" ],
        "site_url" => [ "Webseite", "Website", "Site Web" ],
        "sous_type" => [ "Typ", "Type", "Type" ],
        "surface" => [ "Fläche (m2)", "Surface (m2)", "Surface (m2)" ],
        "surface_balcon" => [ "Fläche Balkon (m2)", "Balcony surface (m2)", "Surface balcon (m2)" ],
        "surface_commerciale" => [ "Handelsfläche (qm)", "Commercial surface (m2)", "Surface commerciale (m2)" ],
        "surface_depot" => [ "Lagerfläche", "Storage surface (m2)", "Surface dépôt" ],
        "surface_habitable" => [ "Wohnfläche (qm)", "Living surface (m2)", "Surface habitable (m2)" ],
        "surface_jardin" => [ "Gartenfläche (qm)", "Garden surface (m2)", "Surface jardin (m2)" ],
        "surface_ter" => [ "Grundstücksfläche (m2)", "Surface area of land", "Surface du terrain (m2)" ],
        "surface_terrasse" => [ "Terrassenfläche (qm)", "Terrasse surface (m2)", "Surface terrasse (m2)" ],
        "surface_utile" => [ "Nützliche Fläche", "Usable surface (m2)", "Surface utile" ],
        "surface_utilisable" => [ "Nutzfläche (qm)", "Usable surface (m2)", "Surface utilisable (m2)" ],
        "vente_etrangers" => [ "Verkauf an Ausländer", "Sale to foreigners", "Vente aux non résidents" ],
        "vol_eca" => [ "Volumen (m3)", "Volume (m3)", "Volume (m3)" ],
        "vue" => [ "Aussicht", "View", "Vue" ],
    ];
    
    /**
     * Get the translation key from the $data table using a given string
     *
     * @param string $string the translated string from which you want to retrieve a key
     * @return mixed the key or false if nothing has been found
     */
    public static function getKeyFromString($string)
    {
        $string = trim($string);
        
        foreach (self::$data as $key => $translationList) {
            if (in_array($string, $translationList)) {
                return $key;
            }
        }

        // that's an unknown key
        return $string;
    }

    /**
     * Get the translation key from the $data table using a given string
     *
     * @param object $technicalDataList the technical data received from the object
     * @return mixed the generated table
     */
    public static function getKeyedTechnicalData($technicalDataList)
    {
        $generatedData = [];
        $lost = [];
        foreach ($technicalDataList as $technicalData) {
            $generatedData[self::getKeyFromString($technicalData->name)] = $technicalData;
            if (self::getKeyFromString($technicalData->name) == false) {
                $lost[] = 'key not found '.$technicalData->name.'<br>';
            }
        }

        return $generatedData;
    }

    /**
     * Get an extraction of the technical data list by keys
     *
     * @param table $technicalDataList the keyed technical data 
     * @param table $toExtractList a table of keys to extract
     * @return mixed the generated table
     */
    public static function extract(&$technicalDataList, $toExtractList)
    {
        $generatedData = [];

        foreach ($toExtractList as $toExtract) {
            if (isset($technicalDataList[$toExtract])) {
                $generatedData[$toExtract] = $technicalDataList[$toExtract];
                unset($technicalDataList[$toExtract]);
            }
        }

        return $generatedData;
    }

}
