<?php
/*
Plugin Name: Publimmo API connecting
description: Allows you to connect to the Publimmo API to retrieve data from a client agency at Publimmo.
Version: 1.2
Author: Valdev
Author URI: https://valdev.ch/
Text Domain: publimmo
Domain Path: /languages
*/

use Classes\Bwap\Queue;
use Classes\PublimmoPro\Client;
use Classes\PublimmoPro\ObjectCollection;
use Classes\PublimmoPro\Objet;

define('THEME_URI', plugin_dir_path( __FILE__ ));

include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Client.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Mailer.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/ObjectCollection.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/ObjectEntity.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Subtypes.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Types.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/ObjetsSearchEngine.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Objet.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/Tools.php';
include plugin_dir_path( __FILE__ ) . 'Classes/PublimmoPro/TechnicalData.php';

include plugin_dir_path( __FILE__ ) . 'Classes/Bwap/DBCache.php';
include plugin_dir_path( __FILE__ ) . 'Classes/Bwap/Queue.php';

function publimmo_listing_short_code_function($atts = array() ) {

    $params = [
        'properties-number' => 9,
        'display-filter-area' => true,
        'display-filter-properties-type' => true,
        'lang' => 'fr'
    ];

    // set up default parameters
    $params = shortcode_atts($params, $atts);

    if(is_array($atts)){
        $params = array_merge($params, $atts);
    }

    ob_start();
    include('template/listing.php');
    $stringa = ob_get_contents();
    ob_end_clean();
    return $stringa;

}

add_shortcode('publimmo-listing', 'publimmo_listing_short_code_function');

add_action( 'admin_menu', 'stp_api_add_admin_menu' );
add_action( 'admin_init', 'stp_api_settings_init' );

function stp_api_add_admin_menu(  ) {
    add_options_page( __('Réglage Publimmo', 'publimmo'), __('Réglage Publimmo', 'publimmo'), 'manage_options', 'settings-api-page', 'stp_api_options_page' );
}

function stp_api_settings_init(  ) {
    register_setting( 'stpPlugin', 'publimmo_settings' );
    add_settings_section(
        'stp_api_stpPlugin_section',
        __( 'Paramètres du plugin Publimmo', 'publimmo' ),
        'stp_api_settings_section_callback',
        'stpPlugin'
    );

    add_settings_field(
        'agency_id',
        __( 'ID de l\'agence', 'publimmo' ),
        'stp_api_text_field_0_render',
        'stpPlugin',
        'stp_api_stpPlugin_section'
    );

    add_settings_field(
        'primary_color',
        __( 'Couleur principale', 'publimmo' ),
        'stp_api_text_field_1_render',
        'stpPlugin',
        'stp_api_stpPlugin_section'
    );

    add_settings_field(
        'secondary_color',
        __( 'Couleur secondaire', 'publimmo' ),
        'stp_api_text_field_2_render',
        'stpPlugin',
        'stp_api_stpPlugin_section'
    );

}

function stp_api_settings_section_callback( $arg ) {

}

function stp_api_text_field_0_render(  ) {
    $options = get_option( 'publimmo_settings' );
    $value = '';
    if(isset($options['agency_id']))
        $value = $options['agency_id']
    ?>
    <input type='text' name='publimmo_settings[agency_id]' value='<?= $value ?>'>
    <?php
}

function stp_api_text_field_1_render(  ) {
    $options = get_option( 'publimmo_settings' );
    $value = '';
    if(isset($options['primary_color']))
        $value = $options['primary_color']
    ?>
    <input type='text' name='publimmo_settings[primary_color]' value='<?= $value ?>'>
    <?php
}

function stp_api_text_field_2_render(  ) {
    $options = get_option( 'publimmo_settings' );
    $value = '';
    if(isset($options['secondary_color']))
        $value = $options['secondary_color']
    ?>
    <input type='text' name='publimmo_settings[secondary_color]' value='<?= $value ?>'>
    <?php
}

function stp_api_options_page(  ) {
    ?>
    <form action='options.php' method='post'>

        <?php
        settings_fields( 'stpPlugin' );
        do_settings_sections( 'stpPlugin' );
        submit_button();
        ?>

    </form>
    <?php
}


add_action('wp_enqueue_scripts', function(){
    global $post;
    $id = get_query_var('objId', false);
    if (has_shortcode ($post->post_content, 'publimmo-listing') || $id ) {

        wp_register_style('get-style', plugins_url('/css/style.css', __FILE__), array(), '1.0.5', 'all');
        wp_enqueue_style('get-style');

        wp_register_style('get-font-awesome', plugins_url('/css/font-awesome.min.css', __FILE__), array(), '4.0.3', 'all');
        wp_enqueue_style('get-font-awesome');

        //wp_deregister_style('owl-carousel');
        //wp_deregister_style('owlCarousel');
        //wp_deregister_script('modernizr');
        //wp_deregister_script('jquery');
        //wp_deregister_script('jquery-core');
        wp_deregister_script('jquery-ui');
        wp_deregister_script('bundle');
        wp_deregister_script('get-autocomplete');
        wp_deregister_script('get-magnific-popup');
        wp_deregister_script('get-touch-swipe');
        wp_deregister_script('get-scripts');
        wp_deregister_script('get-communes');
        wp_deregister_script('get-custom');
        wp_deregister_script('bootstrap');
        wp_deregister_script('wpdevelop-bootstrap');

        wp_register_script('jquery', plugins_url('/js/jquery.min.js', __FILE__), array(), '3.5.1', true);
        wp_enqueue_script('jquery');

        wp_register_script('jquery-ui', plugins_url('/js/jquery-ui.min.js', __FILE__), array('jquery'), '1.12.1', true);
        wp_enqueue_script('jquery-ui');

        wp_register_script('bundle', plugins_url('/js/bundle.js', __FILE__), array('jquery', 'jquery-ui'), '1.0.4', true);
        wp_localize_script('bundle', 'config', [
            'favorites_active' => get_option('favorites', 'inactive'),
            'watermark' => [
                'image' => get_option('img-watermark', false),
                'opacity' => get_option('opacity-watermark', 0.5),
            ],

            'budgetRange' => [
                'rent' => [
                    'min' => (int)get_option('budget_rent_min', 500) ?: 500,
                    'max' => (int)get_option('budget_rent_max', 50000) ?: 50000,
                    'step' => (int)get_option('budget_rent_step', 500) ?: 500,
                ],
                'buy' => [
                    'min' => (int)get_option('budget_buy_min', 50000) ?: 50000,
                    'max' => (int)get_option('budget_buy_max', 10000000) ?: 10000000,
                    'step' => (int)get_option('budget_buy_step', 25000) ?: 25000,
                ],
            ]
        ]);

        wp_localize_script('bundle', 'lang', [
            'favorites' => [
                'my_favorites' => __('Mes favoris', 'publimmo'),
                'consult' => __('consulter', 'publimmo'),
                'remove' => __('retirer', 'publimmo'),
            ],
            'picture_url' => plugins_url('/css/images/ajax-loader.gif', __FILE__)
        ]);
        wp_enqueue_script('bundle');

        wp_register_script('get-autocomplete', plugins_url('/js/autoComplete.js', __FILE__), array('jquery', 'jquery-ui'), '1.0.0', true);
        wp_enqueue_script('get-autocomplete');

        wp_register_script('get-magnific-popup', plugins_url('/js/jquery.magnific-popup.min.js', __FILE__), array('jquery', 'jquery-ui'), '1.0.0', true);
        wp_enqueue_script('get-magnific-popup');

        wp_register_script('get-touch-swipe', plugins_url('/js/jquery.touchSwipe.min.js', __FILE__), array('jquery', 'jquery-ui'), '1.0.0', true);
        wp_enqueue_script('get-touch-swipe');

        wp_register_script( 'get-scripts', plugins_url( '/js/scripts.js', __FILE__ ), array('jquery', 'jquery-ui'), '1.0.9', true );
        wp_enqueue_script( 'get-scripts' );

        wp_register_script( 'get-communes', plugins_url( '/js/list.communes.js', __FILE__ ), array('jquery', 'jquery-ui'), '1.0.0', true );
        wp_enqueue_script( 'get-communes' );

        wp_register_script('bootstrap', plugins_url('/js/bootstrap.bundle.min.js', __FILE__), array('jquery', 'jquery-ui'), '4.5.3', true);
        wp_enqueue_script('bootstrap');

        wp_register_script('get-custom', plugins_url('/js/custom.js', __FILE__), array('jquery', 'jquery-ui', 'bootstrap'), '1.0.3', true);
        wp_enqueue_script('get-custom');

    }

},1);

function create_pagination($total_items, $targetpage, $limit, $hash = null){
    $adjacents = 3;

    if(isset($_GET['show'])) {
        $page = $_GET['show'];
        $start = ($page - 1) * $limit;
    } else {
        $page = 0;
        $start = 0;
    }
    if ($page == 0) {
        $page = 1;
    }
    $prev = $page - 1;
    $next = $page + 1;
    $lastpage = ceil($total_items/$limit);
    $lpm1 = $lastpage - 1;
    $pagination = '';

    $elementFilters = array(
        array(
            'label' => __("Prix croissant", "publimmo"),
            'value' => '02'
        ),
        array(
            'label' => __("Prix décroissant", "publimmo"),
            'value' => '01'
        ),
        array(
            'label' => __("Pièces croissant", "publimmo"),
            'value' => 12
        ),
        array(
            'label' => __("Pièces décroissant", "publimmo"),
            'value' => 11
        ),
        array(
            'label' => __("Surface croissant", "publimmo"),
            'value' => 22
        ),
        array(
            'label' => __("Surface décroissant", "publimmo"),
            'value' => 21
        ),
    );

    $triSelected = 0;
    if(isset($_GET['tri'])){
        $triSelected = $_GET['tri'];
    }
    $triSens = 2;
    if(isset($_GET['triSens'])){
        $triSens = $_GET['triSens'];
    }
    $toSelected = $triSelected."".$triSens;

    if($lastpage > 1){
        $pagination .= '<div>';
        $pagination .= '<div class="col-sm-8"><ul class="pagination pagination_nojax">';
        if($page > 1){
            $pagination.= '<li class="roundleft"><a href="'.$targetpage.'&show='.$prev.$hash.'"><i class="fa fa-angle-left"></i></a></li>';
        } else {
            $pagination.= '<li class="disabled roundleft"><a href="javascript:void(0)"><i class="fa fa-angle-left"></i></a></li>';
        }
        if ($lastpage < 7 + ($adjacents * 2)) {
            for ($counter = 1; $counter <= $lastpage; $counter++) {
                if ($counter == $page) {
                    $pagination.= '<li class="active"><a href="javascript:void(0)">'.$counter.'</a></li>';
                } else {
                    $pagination.= '<li><a href="'.$targetpage.'&show='.$counter.$hash.'">'.$counter.'</a></li>';
                }
            }
        } elseif($lastpage > 5 + ($adjacents * 2)) {
            if($page < 1 + ($adjacents * 2)) {
                for ($counter = 1; $counter < 4 + ($adjacents * 2); $counter++) {
                    if ($counter == $page) {
                        $pagination.= '<li class="active"><a href="javascript:void(0)">'.$counter.'</a></li>';
                    } else {
                        $pagination.= '<li><a href="'.$targetpage.'&show='.$counter.$hash.'">'.$counter.'</a></li>';
                    }
                }
                $pagination.= '<li><a href="javascript:void(0)">...</a></li>';
                $pagination.= '<li><a href="'.$targetpage.'&show='.$lpm1.$hash.'">'.$lpm1.'</a></li>';
                $pagination.= '<li><a href="'.$targetpage.'&show='.$lastpage.$hash.'">'.$lastpage.'</a></li>';
            } elseif($lastpage - ($adjacents * 2) > $page && $page > ($adjacents * 2)) {
                $pagination.= '<li><a href="'.$targetpage.'&show=1'.$hash.'">1</a></li>';
                $pagination.= '<li><a href="'.$targetpage.'&show=2'.$hash.'">2</a></li>';
                $pagination.= '<li><a href="javascript:void(0)">...</a></li>';
                for ($counter = $page - $adjacents; $counter <= $page + $adjacents; $counter++)
                {
                    if ($counter == $page) {
                        $pagination.= '<li class="active"><a href="javascript:void(0)">'.$counter.'</a></li>';
                    } else {
                        $pagination.= '<li><a href="'.$targetpage.'&show='.$counter.$hash.'">'.$counter.'</a></li>';
                    }
                }
                $pagination.= '<li><a href="javascript:void(0)">...</a>';
                $pagination.= '<li><a href="'.$targetpage.'&show='.$lpm1.$hash.'">'.$lpm1.'</a></li>';
                $pagination.= '<li><a href="'.$targetpage.'&show='.$lastpage.$hash.'">'.$lastpage.'</a></li>';
            } else {
                $pagination.= '<li><a href="'.$targetpage.'&show=1'.$hash.'">1</a></li>';
                $pagination.= '<li><a href="'.$targetpage.'&show=2'.$hash.'">2</a></li>';
                $pagination.= '<li><a href="javascript:void(0)">...</a>';
                for ($counter = $lastpage - (2 + ($adjacents * 2)); $counter <= $lastpage; $counter++) {
                    if ($counter == $page){
                        $pagination.= '<li class="active"><a href="javascript:void(0)">'.$counter.'</a></li>';
                    } else {
                        $pagination.= '<li><a href="'.$targetpage.'&show='.$counter.$hash.'">'.$counter.'</a></li>';
                    }
                }
            }
        }
        if($page < $counter - 1){
            $pagination .= '<li class="roundright"><a href="'.$targetpage.'&show='.$next.$hash.'"><i class="fa fa-angle-right"></i></a></li>';
        } else {
            $pagination .= '<li class="disabled roundright"><a href="javascript:void(0)"><i class="fa fa-angle-right"></i></a></li>';
        }
        $pagination .= '</ul></div>';
        if($page == 1){
            $first_element = "1";
            $last_element = $limit;
        }elseif($page == $lastpage){
            $first_element = (($page-1)*$limit)+1;
            $last_element = $total_items;
        }else{
            $first_element = (($page-1)*$limit)+1;
            $last_element = $page*$limit;
        }
        $pagination .= '<div class="clearfix visible-xs"></div><div class="col-sm-4"><div class="pagination-total text-right">';
        $pagination .= '';
        $pagination .= '<h5>'.$first_element.' - '.$last_element.' '.__("sur","publimmo").' '.$total_items.' '.__("résultats","publimmo").'</h5></div>';

        $pagination .= '<div style="text-align: right;"><select id="filters">';
        foreach ($elementFilters as $elementFilter) {
            $pagination.= '<option ';

            if($toSelected == $elementFilter['value']){
                $pagination .= 'selected="selected" ';
            }
            $pagination .= 'value="'.$elementFilter['value'].'">'.$elementFilter['label'].'</option>';
        }

        $pagination .= '</select></div>';
        $pagination.= '</div><div class="clearfix"></div></div>';
    }
    else{
        $pagination .= '<div class="col-sm-12">';
        $pagination .= '<div class="pagination-total text-right"><h5>'.$total_items.' '.__("résultats","publimmo").'</h5></div>';
        $pagination .= '<div style="text-align: right;"><select id="filters">';

        foreach ($elementFilters as $elementFilter) {
            $pagination.= '<option ';

            if($toSelected == $elementFilter['value']){
                $pagination .= 'selected="selected" ';
            }
            $pagination .= 'value="'.$elementFilter['value'].'">'.$elementFilter['label'].'</option>';
        }
        $pagination .= '</select></div>';
        $pagination .= '</div><div class="clearfix"></div>';
    }
    $pagination .= '<div class="adv-search-1"><div class="col-sm-3 ">                        
                                       
                        <div id="value-transaction" data-transaction=""></div>
                </div></div>';
    $end = $start + $limit - 1;
    return array('pagination' => $pagination, 'i' => $start, 'end' => $end);
}

function renderTags($objet) {
    echo '<div>';
    if ($objet->data->disponibiliteCode != 0 && $objet->data->disponibilite) {
        echo '<div class="tag-wrapper"><div class="featured_div featured_div_dispo">'.$objet->data->disponibilite.'</div></div>';
    }

    if (isset($objet->data->locationType)) {
        if ($objet->data->locationType == 1) {
            echo '<div class="tag-wrapper"><div class="featured_div featured_div_dispo">'.__('Location à la semaine','publimmo').'</div></div>';
        } elseif ($objet->data->locationType == 2) {
            echo '<div class="tag-wrapper"><div class="featured_div featured_div_dispo">'.__('Location saisonnière','publimmo').'</div></div>';
        }
    }

    if (!empty($objet->data->movie)) {
        echo '<div class="tag-wrapper tag-wrapper-movie"><div class="featured_div featured_div_video">'.__('Spot Video','publimmo').'</div></div>';
    }

    if (!empty($objet->data->virtualVisit)) {
        echo '<div class="tag-wrapper tag-wrapper-movie"><div class="featured_div featured_div_video">'.__("Visite 360°","publimmo").'</div></div>';
    }
    echo '</div>';
}

/**
 * @param $obj_all \Classes\PublimmoPro\ObjetsSearchEngine
 * @param $i
 * @param string $objType
 * @param $type_de_listing
 */
function show_object($obj_all, $i, $objType = 'default', $type_de_listing){

    if (!isset($obj_all->results[$i]) || count($obj_all->results) == 0) {
        return;
    }

    if($objType == "promotion"){
        $objType = "promo";
    } else if($objType == 'composed') {
        $objType = 'composed';
    }else{
        $objType = "default";
    }

    $objet = new Objet(array(
        'object_data' => $obj_all->results[$i],
        'displayType' => $objType
    ));
    if(isset($objet->data->photo) && $objet->data->photo != '') {
        if(strpos($objet->data->photo, 'gallery-cropped') === false) {
            $objet->data->photo = str_replace(array('gallery','small'),array('gallery-cropped','gallery-cropped'),$objet->data->photo);
        }
        $img_url = $objet->data->photo;
    } else {
        $img_url = get_template_directory_uri().'/images/noimg.png';
    }

    $object_url = $objet->getUrl();
    $object_title = $objType == 'composed'
        ? $objet->data->titre
        : $objet->getTitlev2();

    if ($objType == 'composed' && !empty($objet->data->soustitre)) {
        $object_title .= '<br><small>'.$objet->data->soustitre.'</small>';
    }

    $object_price = $objet->getPrice(get_option("priceshow",'chf'));
    $useWatermark = 'oui';

    switch ($type_de_listing) {
        case 'carousel':
            $column = 'in-carousel';
            $modifier = '';
            break;

        case 'grille':
            $column = '';
            $modifier = '';
            break;

        case 'grille_simple':
            $column = '';
            $modifier = 'object-teaser--simple';
            break;

        case 'liste':
        default:
            $column = '';
            $modifier = 'object-teaser--horizontal';
    }

    ?>
    <div class="object-teaser <?= $column ?> <?= $modifier ?> property_listing" data-link="">
        <?php
        // print only image
        /*
         * this has been disabled because it loads images and affect performance
        echo '<img
            class="visible-print-block"
            src="'.$img_url.'"
            alt=""
            />';
         */
        ?>
        <div class="object-teaser__media listing-unit-img-wrapper">

            <div class="property_media"></div>

            <a href="<?= $object_url ?>" <?= (!empty($objet->data->locationSaisonniereUrl) ? 'target="_blank" rel="noreferrer noopener"' : '') ?>>
                <div id="property_unit_carousel_<?php echo $objet->data->id; ?>" class="carousel property_unit_carousel slide" data-ride="carousel" data-interval="false">
                    <div class="carousel-inner">
                        <div class="item active">
                            <?php
                            if ($useWatermark) {
                                echo '<img alt="'.str_replace('"', "'", $object_title).'" class="img-responsive watermark" src="'.$img_url.'">';
                            } else {
                                echo '<div class="lazy slide-image" data-src="'.$img_url.'"></div>';
                            }
                            ?>
                        </div>
                        <?php
                        if(!empty($objet->data->photos) && $type_de_listing != 'grille_simple'){
                            foreach($objet->data->photos as $k => $image){
                                if(strpos($image, 'gallery-cropped') === false) {
                                    $image = str_replace(array('gallery','small'),array('gallery-cropped','gallery-cropped'),$image);
                                }
                                ?>
                                <div class="item">
                                    <?php
                                    if ($useWatermark) {
                                        echo '<img alt="'.str_replace('"', "'", $object_title).'" class="img-responsive watermark" src="'.$image.'">';
                                    } else {
                                        echo '<div class="lazy slide-image" data-src="'.$image.'"></div>';
                                    }
                                    ?>
                                </div>
                                <?php

                                // limit images to 3
                                if ($useWatermark && $k == 1) {
                                    break;
                                }
                            }
                        }
                        ?>
                    </div>
            </a>
            <?php
            if(!empty($objet->data->photos) && $type_de_listing != 'grille_simple'){ ?>
                <a class="left  carousel-control" href="#property_unit_carousel_<?= $objet->data->id; ?>" data-slide="prev">
                    <i class="demo-icon icon-left-open-big"></i>
                </a>
            <a class="right  carousel-control" href="#property_unit_carousel_<?= $objet->data->id; ?>" data-slide="next">
                    <i class="demo-icon icon-right-open-big"></i>
                </a><?php
            } ?>
        </div>
        <?php
        if ($type_de_listing != 'grille_simple') {
            renderTags($objet);
        }
        ?>
    </div>
    <a href="<?= $object_url ?>" <?= (!empty($objet->data->locationSaisonniereUrl) ? 'target="_blank" rel="noreferrer noopener"' : '') ?> class="d-block">
        <div class="object-teaser__content">
            <?php
            if($objType != "promo" && $type_de_listing !== 'grille_simple'){ ?>
                <div class="object-teaser__title"><?= $object_title ?></div>
                <?php if ($objet->data->transaction) { ?>
                    <div class="object-teaser__subtitle"> <?= $objet->data->transaction; ?> </div>
                <?php } ?>
                <div class="object-teaser__price"><?= $object_price ?></div>
                <?php
                $pictoSize = [
                    'w' => 24,
                    'h' => 22
                ];

                if (!empty($objet->data->parcs)){
                    $infos[] = renderTeaserInfo('<svg class="object-teaser__info-picto" width="'.$pictoSize['w'].'" height="'.$pictoSize['h'].'" viewBox="0 0 98 90"><use href="' . plugin_dir_url( __FILE__ ) . 'css/images/picto_parc.svg#picto_parc' . '"></use></svg>', __("Parking", "publimmo"));
                } elseif (isset($objet->data->vue)) {
                    $infos[] = renderTeaserInfo('<i class="fa fa-eye" aria-hidden="true"></i>', __("Vue", "publimmo"));
                    unset($objet->data->vue);
                }

                if (!empty($objet->data->garages)) {
                    $infos[] = renderTeaserInfo('<svg class="object-teaser__info-picto" width="'.$pictoSize['w'].'" height="'.$pictoSize['h'].'" viewBox="0 0 98 90"><use href="' . plugin_dir_url( __FILE__ ) . 'css/images/picto_garage.svg#picto_garage' . '"></use></svg>', __("Garage", "publimmo"));
                } elseif (isset($objet->data->vue)) {
                    $infos[] = renderTeaserInfo('<i class="fa fa-eye" aria-hidden="true"></i>', __("Vue", "publimmo"));
                }

                if (!empty($objet->data->surface)) {
                    $infos[] = renderTeaserInfo($objet->data->surface, __("Surface [m<sup>2</sup>]", "publimmo"));
                } elseif (isset($objet->data->m3)) {
                    $infos[] = renderTeaserInfo($objet->data->m3, __("Volume [m<sup>3</sup>]", "publimmo"));
                }

                if (!empty($infos)) {
                    echo '<div class="object-teaser__infos">'.implode('<div class="object-teaser__info-seperator"></div>', $infos).'</div>';
                }
            } else  {
                // object type is "promo"
                ?>
                <div class="object-teaser__title"><?= $object_title ?></div>
                <?php
                if (!empty($objet->data->lots) && $type_de_listing != 'grille_simple') {
                    ?>
                    <div class="infos-promo">
                        <div class="row">
                            <?php echo getListPromo($objet->data->lots); ?>
                        </div>
                    </div>
                    <?php
                }
            }
            ?>
        </div>
    </a>
    </div>
    <?php
}


function renderTeaserInfo($value = '', $title = '') {
    return '<div class="object-teaser__info">'.$value.'<div class="object-teaser__info-label">'.$title.'</div></div>';
}

function wptuts_add_rewrite_rules() {
    add_rewrite_rule(
        '^([^/]*)/([^/]*)/([^/]*)/([^/]+)/?$',
        'index.php?objId=$matches[4]',
        'top'
    );

    flush_rewrite_rules();

}
add_action( 'init', 'wptuts_add_rewrite_rules' );

function filter_template( $template ){

    $id = get_query_var('objId', false);
    if($id){
        add_filter( 'template_include', function() {
            $custom_template = dirname(__FILE__) .  '/template/page-objet.php';
            return $custom_template;
        });
    }
    return $template;
}
add_filter('template_redirect', 'filter_template');

function myplugin_register_query_vars( $vars ) {
    $vars[] = 'objId';
    return $vars;
}
add_filter( 'query_vars', 'myplugin_register_query_vars' );

function getSearchParams(){
    if (isset($_COOKIE['search_list']) && isset($_COOKIE['search_page'])) {
        return [
            'request' => $_COOKIE['search_page'],
            'list' => json_decode($_COOKIE['search_list']),
        ];
    } else {
        return false;
    }
}

function getAnchorMenu($objet){
    if(!empty($objet->data->adresse) && !empty($objet->data->transaction) && $objet->data->transaction == "A Louer"){ ?>
        <li><a href="#property_address_title"><?php _e("Adresse", "publimmo"); ?></a></li><?php
    }
    if(!empty($objet->data->pieces) || !empty($objet->data->surface)){ ?>
        <li><a href="#property_pces_title"><?php _e("Pièces et mesures", "publimmo"); ?></a></li><?php
    }
    if(!empty($objet->data->parcs) || !empty($objet->data->garages)){ ?>
        <li><a href="#property_parc_title"><?php _e("Parc(s) et garage(s)", "publimmo"); ?></a></li><?php
    }
    if(!empty($objet->data->technicalData)){ ?>
        <li><a href="#property_data_title"><?php _e("Données complémentaires", "publimmo"); ?></a></li><?php
    }
    if(!empty($objet->data->plans)){ ?>
        <li>
        <a href="#property_floor_title"><?php
            if(count($objet->data->plans) == 1){
                _e("Plan", "publimmo");
            }else{
                _e("Plans", "publimmo");
            } ?>
        </a>
        </li><?php
    }
    if(!empty($objet->data->annexes)){ ?>
        <li>
        <a href="#prop_annexe_title"><?php
            if(count($objet->data->annexes) == 1){
                _e("Annexe", "publimmo");
            }else{
                _e("Annexes", "publimmo");
            } ?>
        </a>
        </li><?php
    }
    if(!empty($objet->data->promotionTable)){ ?>
        <li><a href="#prop_promotion_table_title"><?php _e("Liste des lots de cette promotion","publimmo"); ?></a></li><?php
    }
    if(!empty($objet->data->pano360)){ ?>
        <li>
        <a href="#prop_pano360_title"><?php
            if(count($objet->data->pano360) == 1){
                _e("Panorama 360°", "publimmo");
            }else{
                _e("Panoramas 360°", "publimmo");
            } ?>
        </a>
        </li><?php
    }
    ?>
    <li class="li-anchor-btn-dossier"><a class="anchor-btn-dossier" href="#demande-de-dossier"><?php _e('Demande de dossier','publimmo'); ?></a></li>
    <?php
}


function remove_sidebar( $is_active_sidebar, $index ) {
    global $post;

    $id = get_query_var('objId', false);
    if($id || has_shortcode ($post->post_content, 'publimmo-listing') ) {
        return false;
    }
    return $is_active_sidebar;
}

add_filter( 'is_active_sidebar', 'remove_sidebar', 10, 2 );

add_filter( 'body_class', 'add_body_class' );
function add_body_class( $classes ) {
    global $post;

    $id = get_query_var('objId', false);
    if($id || has_shortcode ($post->post_content, 'publimmo-listing') ) {
        $classes[] = 'publimmo-custom-plugin-listing-body';
    }
    // return the $classes array
    return $classes;
}

function renderCheckbox($label, $name, $value = '1', $id = null, $attr = null){
    $id = ($id)?$id:$name;
    if (isset($_GET[$name]) && $_GET[$name] == $value) {
        $attr .= ' checked';
    }
    return '<div class="checkbox"><input type="checkbox" class="js-checkbox" name="'.$name.'" value="'.$value.'" id="'.$id.'" '.$attr.'/><label class="js-label" for="'.$id.'" id="'.sanitize_title($id).'">'.$label.'</label></div>';
}

add_action( 'wp_ajax_getref', 'getref_callback' );
add_action( 'wp_ajax_nopriv_getref', 'getref_callback' );

function getref_callback() {
    $return = [
        'status' => 0,
        'msg' => __('Ce numéro de référence n\'existe pas','publimmo'),
        'fieldID' => 'ref',
    ];

    $objet = new Objet(array(
        'object_ID' => $_GET['idRef']
    ));

    if ($objet) {
        $return['msg'] = $objet->getUrl();
        $return['status'] = 1;
    }

    die(json_encode($return));
}

function my_plugin_load_plugin_textdomain() {
    load_plugin_textdomain( 'publimmo', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'my_plugin_load_plugin_textdomain' );

/***
 * Formulaires Ajax
 */
add_action( 'wp_ajax_sendform', 'sendform_callback' );
add_action( 'wp_ajax_nopriv_sendform', 'sendform_callback' );

function sendform_callback() {
    $return = array(
        'status'=>1,
        'msg'=> __('Merci de nous avoir contacté. Nous vous répondrons dans les plus brefs délais.','publimmo'),
        'fieldID'=>''
    );

    if(filter_var($_POST['input_5'], FILTER_VALIDATE_EMAIL) == false) {
        $return['status'] = 0;
        $return['msg'] = __('L\'adresse email indiquée n\'est pas valide.','publimmo');
        $return['fieldID'] = '#input_1_5';
    }

    if($return['status'] == 1) {
        include dirname( __FILE__ ) . '/template/forms/email.'.$_POST['form'].'.tpl.php';

        $headers[] = 'From: Publimmo.pro <'.$from.'>';
        $headers[] = 'Content-type: text/html; charset=UTF-8';
        $headers[] = 'Bcc: archivage@publimmo.ch';

        $mail_sent = Queue::addMessage('send_mail', [
            'sendTo' => $sendTo,
            'subject' => $subject,
            'message' => stripslashes($html),
            'headers' => $headers
        ]);

        if (!$mail_sent) {
            $return = array(
                'status'=>0,
                'msg'=> __('Une erreur est survenue lors de l\'envoi de votre email, veuillez essayez à nouveau dans quelques instants.','publimmo-forms'),
            );
        }
    }
    ob_clean();
    die(json_encode($return));
}
