<?php
/*
*    Template name: Détail d'un objet
*/

global $wp_query;

use Classes\PublimmoPro\Objet;
use Classes\PublimmoPro\TechnicalData;

$id = get_query_var('objId', false);
if(!$id) {
    wp_redirect( home_url()); exit;
}

if(!defined('ICL_LANGUAGE_CODE')) {
    define('ICL_LANGUAGE_CODE', 'fr');
    define('LOCALE_WITH_TERRITORY', 'fr_FR');
}

$objet = $GLOBALS['pi_object'] = new Objet('object_ID='.$id);
if(empty($GLOBALS['pi_object']->data)) {
    wp_redirect( home_url()); exit;
}

$objectUrl = $objet->getUrl();
if (strpos($_SERVER['REQUEST_URI'], '/o/')) {
    add_action('wp_head', function () use ($objectUrl) {
        echo '<link rel="canonical" href="'.$objectUrl.'" />';
    });

    add_action('wp_footer', function () use ($objectUrl) {
        echo '<script>history.replaceState("", "", "'.$objectUrl.'");</script>';
    });
}

$page_layouts['sidebar'] = '';

/**
 * Triaging of technicalData in specific groups
 */
$technicalDataList = TechnicalData::getKeyedTechnicalData($objet->data->technicalData);
$technicalGroups = [
    [
        'name' => __('Nombre de pièces et surfaces', 'publimmo'),
        'id' => 'property_pces',
        'dataList' => technicalData::extract($technicalDataList, [
            'nb_pieces',
            'nb_chambres',
            'nb_sallesdebain',
            'surface_habitable',
            'surface_balcon',
            'surface_terrasse',
            'surface_jardin',
            'surface',
            'surface_ter',
            'etage',
            'surface_utilisable',
            'vol_eca',
            'nb_logements',
            'nb_vitrines',
            'rendement_brut',
            'rendement_net',
            'surface_commerciale',
            'surface_utile',
            'surface_depot',
        ])
    ],
    [
        'name' => __('Parcs et garages', 'publimmo'),
        'id' => 'property_parc',
        'dataList' => TechnicalData::extract($technicalDataList, ['nb_garages', 'nb_boxes', 'nb_parcint', 'nb_parccouv', 'nb_parcext'])
    ],
    [
        'name' => __('Données complémentaires', 'publimmo'),
        'id' => 'property_data',
        'dataList' => $technicalDataList
    ],
];

$primaryColor = "#492714";
$secondaryColor = "#222";
if( get_option('publimmo_settings')['primary_color'] &&  get_option('publimmo_settings')['primary_color'] != ""){
    $primaryColor = get_option('publimmo_settings')['primary_color'];
}

if( get_option('publimmo_settings')['secondary_color'] &&  get_option('publimmo_settings')['secondary_color'] != ""){
    $secondaryColor = get_option('publimmo_settings')['secondary_color'];
}

get_header();
//todo
//$type_gallery = get_option('type_gallery','slideshow');
$type_gallery = "grille";
?>
<style type='text/css'>
    body #publimmo-custom-plugin-listing .adv_handler_refresh,
    body #publimmo-custom-plugin-listing .anchor-btn-dossier {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adv_handler {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adv_handler:hover {
        background-color: <?= $secondaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adv_handler_refresh:active,
    body #publimmo-custom-plugin-listing .adv_handler_refresh:focus,
    body #publimmo-custom-plugin-listing .adv_handler_refresh:hover {
        background-color: <?= $secondaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .caret:after {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adv_search_slider .ui-widget-header {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .pagination > .active > a,
    body #publimmo-custom-plugin-listing .pagination > .active > a:focus,
    body #publimmo-custom-plugin-listing .pagination > .active > a:hover,
    body #publimmo-custom-plugin-listing .pagination > .active > span,
    body #publimmo-custom-plugin-listing .pagination > .active > span:focus,
    body #publimmo-custom-plugin-listing .pagination > .active > span:hover{
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .pagination > li > a:focus,
    body #publimmo-custom-plugin-listing .pagination > li > a:hover,
    body #publimmo-custom-plugin-listing .pagination > li > span:focus,
    body #publimmo-custom-plugin-listing .pagination > li > span:hover {
        background-color: <?= $primaryColor ?>;
        border-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .form-control.open {
        border-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .filter_menu li:hover {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing #submitForm {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing #submitForm:hover {
        background-color: <?= $secondaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .object-teaser__price {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .featured_div {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .form-control:focus {
        border-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adres_area, #publimmo-custom-plugin-listing .adres_area a {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .adv_handler_refresh, #publimmo-custom-plugin-listing .anchor-btn-dossier {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .property_menu li a.anchor-btn-dossier:hover {
        background-color: <?= $secondaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .price_area {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .caret:after {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing #primary .wpresidence_button,
    body #publimmo-custom-plugin-listing .comment-form #submit,
    body #publimmo-custom-plugin-listing .wpresidence_button {
        background-color: <?= $primaryColor ?>
    }

    body #publimmo-custom-plugin-listing #primary .wpresidence_button:hover,
    body #publimmo-custom-plugin-listing .comment-form #submit:hover,
    body #publimmo-custom-plugin-listing .wpresidence_button:hover {
        background-color: <?= $secondaryColor ?>;
    }

    body #publimmo-custom-plugin-listing #primary a:hover {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .form-control.open .sidebar_filter_menu {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .owl-nav .owl-next:hover:after {
        border-bottom-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing a:focus,
    body #publimmo-custom-plugin-listing a:hover {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing .property_menu li a:hover {
        color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing input[type="text"]:focus,
    body #publimmo-custom-plugin-listing input[type="search"]:focus,
    body #publimmo-custom-plugin-listing input[type="email"]:focus,
    body #publimmo-custom-plugin-listing input[type="url"]:focus,
    body #publimmo-custom-plugin-listing input[type="password"]:focus,
    body #publimmo-custom-plugin-listing input[type="tel"]:focus,
    body #publimmo-custom-plugin-listing input[type="number"]:focus,
    body #publimmo-custom-plugin-listing textarea:focus,
    body #publimmo-custom-plugin-listing select.form-control:focus,
    body #publimmo-custom-plugin-listing select:focus {
        border-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing *::selection {
        background-color: <?= $primaryColor ?>;
    }

    body #publimmo-custom-plugin-listing #colophon,
    body #publimmo-custom-plugin-listing .islive:hover,
    body #publimmo-custom-plugin-listing .places_type_2_listings_no .listings_no,
    body #publimmo-custom-plugin-listing .theme_slider_price,
    body #publimmo-custom-plugin-listing .theme_slider_wrapper .carousel-indicators .active,
    body #publimmo-custom-plugin-listing .featured_div_video,
    body #publimmo-custom-plugin-listing .featured_div_dispo,
    body #publimmo-custom-plugin-listing .pagination > .active > a,
    body #publimmo-custom-plugin-listing .pagination > .active > span,
    body #publimmo-custom-plugin-listing .pagination > .active > a:hover,
    body #publimmo-custom-plugin-listing .pagination > .active > span:hover,
    body #publimmo-custom-plugin-listing .pagination > .active > a:focus,
    body #publimmo-custom-plugin-listing .pagination > .active > span:focus,
    body #publimmo-custom-plugin-listing .pagination > li > a:hover,
    body #publimmo-custom-plugin-listing .pagination > li > span:hover,
    body #publimmo-custom-plugin-listing .pagination > li > a:focus,
    body #publimmo-custom-plugin-listing .pagination > li > span:focus,
    body #publimmo-custom-plugin-listing .comment-form #submit,
    body #publimmo-custom-plugin-listing .wpresidence_button,
    body #publimmo-custom-plugin-listing .adv_handler,
    body #publimmo-custom-plugin-listing #slider_price .ui-widget-header,
    body #publimmo-custom-plugin-listing .adv_search_slider .ui-widget-header,
    body #publimmo-custom-plugin-listing .form-collapse i,
    body #publimmo-custom-plugin-listing .property_menu li a.anchor-btn-dossier,
    body #publimmo-custom-plugin-listing .adv_handler_refresh, .footer-object-mobile ul li a,
    body #publimmo-custom-plugin-listing .footer-object-mobile ul,
    body #publimmo-custom-plugin-listing #gmapzoomplus_sh,
    body #publimmo-custom-plugin-listing #gmapzoomplus,
    body #publimmo-custom-plugin-listing #gmapzoomminus_sh,
    body #publimmo-custom-plugin-listing #gmapzoomminus,
    body #publimmo-custom-plugin-listing #gmapzoomplus_sh:hover,
    body #publimmo-custom-plugin-listing #gmapzoomminus_sh:hover,
    body #publimmo-custom-plugin-listing #slider_enable_street_sh:hover,
    body #publimmo-custom-plugin-listing #gmapzoomplus:hover,
    body #publimmo-custom-plugin-listing #gmapzoomminus:hover,
    body #publimmo-custom-plugin-listing #gmapreinit {
        background-color: <?= $primaryColor ?>;
    }
</style>
<div id="publimmo-custom-plugin-listing">
    <div class="<?php if($type_gallery == "slideshow"){echo "template-1";}else{echo "template-2";} if(!empty($searchParams) && ($searchParams['list'] || $searchParams['request'])){}else{echo "";}?>">
    <div id="demande-de-dossier-true"></div>
    <?php
    $searchParams = getSearchParams();
    if($searchParams && ($searchParams['list'] || $searchParams['request'])) { ?>
        <div class="nav-search">
            <div class="container">
                <div class="inner-nav-search">
                    <div class="pull-left back-to-list"><?php
                        if($searchParams['request']) {
                            echo '<a href="'.$searchParams['request'].'"><i class="fa fa-bars primary"></i><span> '.__("Retour à la liste", "publimmo").'</span></a>';
                        } ?>
                    </div>

                    <div class="pull-right next-prev"><?php
                        if($searchParams['list'])
                            foreach($searchParams['list'] as $key => $value) {
                                if($value == get_query_var('id')) {
                                    if(isset($searchParams['list'][$key-1])) {
                                        $previousObjet = new Objet('object_ID='.$searchParams['list'][$key-1]);
                                        echo '<a href="'.$previousObjet->getUrl().'" id="prev_object"><i class="fa fa-angle-left primary"></i><span class="hidden-xs"> '.__("Précédent", "publimmo").'</span></a>';
                                    }
                                    if(isset($searchParams['list'][$key+1])) {
                                        $nextObjet = new Objet('object_ID='.$searchParams['list'][$key+1]);
                                    echo '<a href="'.$nextObjet->getUrl().'" id="next_object"><span class="hidden-xs">'.__("Suivant", "publimmo").' </span><i class="fa fa-angle-right primary"></i></a>';
                                }
                            }
                        } ?>
                    </div>
                    <div class="clearfix"></div>
                </div>
            </div>
        </div><?php
    }
    if(!empty($objet->data->photos) && $type_gallery == "slideshow"){ ?>
        <div class="owl-carousel owl-theme" id="owl-carousel-object">
            <?php
            foreach($objet->data->photos as $k => $image){ ?>
                <div class="item" style="width:auto;">
                    <?php
                    $title = '';

                    if (!empty($image->desc)) {
                        $title .= "<span class='modal-title'>".ucfirst($image->desc)."</span>";
                    }

                    $title .= "<span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                    ?>
                    <a data-clone-target="<?= $k ?>" href="<?php echo str_replace("gallery","fullhd",$image->URL); ?>" data-title="<?php echo $title; ?>">
                        <img src="<?php echo str_replace("gallery","gallery-cropped",$image->URL); ?>" alt="<?php echo ucfirst($image->desc ?? ''); ?>" class="<?php if(get_option('watermark-object-mini') == "oui"){echo "watermark";} ?>" /><?php
                        if (!empty($image->desc)){
                            ?>
                            <span class="object-image-caption"><?php echo ucfirst($image->desc); ?></span><?php
                        }
                        ?>
                    </a>
                </div>
                <?php
            }
            ?>
        </div>
        <div class="prop_title_zone_menu">
            <div class="container prop_title_zone_menu_container">
                <ul class="property_menu">
                    <?php getAnchorMenu($objet); ?>
                </ul>
            </div>
        </div><?php
    } ?>
    <div class=" prop_title_zone with_full_header">
        <div class="container">
            <div class="top-object"><?php
                $titleType = get_option('use_alternative_title','normal');
                if($titleType == "normal"){ ?>
                    <h1 id="prop_categs" class="property_categs">
                        <?php echo $objet->getTitlev2(); ?>
                    </h1><?php
                }
                ?>
                <div class="row">
                    <div class="col-sm-8">
                        <?php
                        switch ($titleType) {
                            case 'alternative':
                                echo '<h1 class="entry-title entry-prop">'.$objet->data->soustitre.'</h1>';
                                break;

                            case 'alternative_plus_title':
                                echo '<h1 class="entry-title entry-prop">'.$objet->getTitlev2().'</h1>';
                                break;

                            case 'normal':
                            default:
                                echo '<div class="entry-title entry-prop h1">'.$objet->data->soustitre.'</div>';
                        }
                        ?>
                        <div class="notice_area"><?php
                            if (!empty($objet->data->locationType)) {
                                if ($objet->data->locationType == 1) {
                                    echo '<div class="h3">'.__('Location à la semaine','publimmo').'</div>';
                                } elseif ($objet->data->locationType == 2) {
                                    echo '<div class="h3">'.__('Location saisonnière','publimmo').'</div>';
                                }
                            }
                            if(isset($objet->data->id)){ ?>
                                <span class="adres_area"><?php echo __("Réf.", "publimmo").': '.$objet->data->id; ?></span><?php
                            }
                            if(isset($objet->data->id) && isset($objet->data->refAgence)){ ?>
                                <span class="adres_area"> / </span><?php
                            }
                            if(isset($objet->data->refAgence)){ ?>
                                <span class="adres_area"><?php echo __("Réf. Agence", "publimmo").': '.$objet->data->refAgence; ?></span><?php
                            } ?>
                        </div>
                    </div>
                    <div class="col-sm-4">
                        <div class="price_area">
                            <?= $objet->getPriceV2(get_option("priceshow",'chf')) ?>
                            <?php
                            if (get_option('display_charges', false) == 'oui' && !empty($technicalDataList['charges_mens']->value)) {
                                echo '<div style="font-size: 50%; font-weight: 400;line-height:1.2;margin-top: .3em">+ '.$technicalDataList['charges_mens']->name.': CHF '.$technicalDataList['charges_mens']->value.'</div>';
                            }
                            ?>
                        </div>
                        <?php
                        if($objet->data->disponibiliteCode != 0 && $objet->data->disponibilite) {
                            echo '<div style="display: inline-block;padding: 5px 10px;background: #333;font-size: 15px; text-transform: uppercase; margin-top: 15px;color:#fff">'.$objet->data->disponibilite.'</div>';
                        }
                        ?>
                    </div>
                </div>
            </div><?php
            if($objet->data->photos && $type_gallery == "grille"){
                $nb_images = count($objet->data->photos); ?>
                <div class="grid-gallery"><?php

                    foreach ($objet->data->photos as $pic){
                        if(!isset($pic->desc)){
                            $pic->desc = "";
                        }
                    }

                     if($nb_images >= 1){

                        $title = "<span class='modal-title'>".ucfirst($objet->data->photos[0]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                         ?>
                        <a href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[0]->URL); ?>" data-title="<?php echo $title; ?>" class="first-image-gallery-grid">
                            <div class="<?php if($nb_images == 1 || $nb_images == 2){echo "col-md-12";}else{echo "col-md-8";} ?> image_gallery special_border" style="background-image:url(<?php echo $objet->data->photos[0]->URL; ?>)  ">
                                <div class="img_listings_overlay"></div><?php
                                if($nb_images == 2){ ?>
                                    <span class="img_listings_mes hidden-xs hidden-sm"><?php _e("Voir toutes les photos","publimmo"); ?></span><?php
                                } ?>
                            </div>
                        </a><?php
                        if($nb_images >= 2){
                            $title = "<span class='modal-title'>".ucfirst($objet->data->photos[1]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                            ?>
                            <a class="hidden visible-xs visible-sm" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[1]->URL); ?>" data-title="<?php echo $title; ?>">
                                <div class="col-md-4 image_gallery" style="background-image:url(<?php echo $objet->data->photos[1]->URL; ?>)  ">
                                    <div class="img_listings_overlay"></div>
                                    <span class="img_listings_mes"><?php _e("Voir toutes les photos","publimmo"); ?></span>
                                </div>
                            </a><?php
                        }
                    }
                    if($nb_images >= 3){
                        $title = "<span class='modal-title'>".ucfirst($objet->data->photos[1]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                        ?>
                        <a class="hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[1]->URL); ?>" data-title="<?php echo $title; ?>">
                            <div class="col-md-4 image_gallery special_border_top" style="background-image:url(<?php echo $objet->data->photos[1]->URL; ?>)  ">
                                <div class="img_listings_overlay"></div>
                            </div>
                        </a><?php
                        $title = "<span class='modal-title'>".ucfirst($objet->data->photos[2]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                         ?>
                        <a class="hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[2]->URL); ?>" data-title="<?php echo $title; ?>">
                            <div class="col-md-4 image_gallery" style="background-image:url(<?php echo $objet->data->photos[2]->URL; ?>)  ">
                                <div class="img_listings_overlay"></div><?php
                                if($nb_images > 3 && $nb_images < 6){ ?>
                                    <span class="img_listings_mes"><?php _e("Voir toutes les photos","publimmo"); ?></span><?php
                                } ?>
                            </div>
                        </a><?php
                        if($nb_images <= 5 && $nb_images > 3){
                                  $title = "<span class='modal-title'>".ucfirst($objet->data->photos[3]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                             ?>
                            <a class="hidden hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[3]->URL); ?>" data-title="<?php echo $title; ?>">
                                <div class="col-md-4 image_gallery" style="background-image:url(<?php echo $objet->data->photos[3]->URL; ?>)  ">
                                    <div class="img_listings_overlay"></div>
                                </div>
                            </a><?php
                        }
                        if($nb_images == 5){
                                  $title = "<span class='modal-title'>".ucfirst($objet->data->photos[4]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                             ?>
                            <a class="hidden hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[4]->URL); ?>" data-title="<?php echo $title; ?>">
                                <div class="col-md-4 image_gallery" style="background-image:url(<?php echo $objet->data->photos[4]->URL; ?>)  ">
                                    <div class="img_listings_overlay"></div>
                                </div>
                            </a><?php
                        }
                    }
                    if($nb_images >= 6){
                         $title = "<span class='modal-title'>".ucfirst($objet->data->photos[3]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                         ?>
                        <a class="hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[3]->URL); ?>" data-title="<?php echo $title; ?>">
                            <div class="col-md-4 image_gallery special_border_left" style="background-image:url(<?php echo $objet->data->photos[3]->URL; ?>)  ">
                                <div class="img_listings_overlay"></div>
                            </div>
                        </a><?php
                          $title = "<span class='modal-title'>".ucfirst($objet->data->photos[4]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                        ?>
                        <a class="hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[4]->URL); ?>" data-title="<?php echo $title; ?>">
                            <div class="col-md-4 image_gallery" style="background-image:url(<?php echo $objet->data->photos[4]->URL; ?>)  ">
                                <div class="img_listings_overlay"></div>
                            </div>
                        </a><?php
                              $title = "<span class='modal-title'>".ucfirst($objet->data->photos[5]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                        ?>
                        <a href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[5]->URL); ?>" data-title="<?php echo $title; ?>" class="hidden-sm hidden-xs">
                            <div class="col-md-4 image_gallery last_gallery_item" style="background-image:url(<?php echo $objet->data->photos[5]->URL; ?>)  ">
                                <div class="img_listings_overlay img_listings_overlay_last"></div><?php
                                if($nb_images > 6){ ?>
                                    <span class="img_listings_mes"><?php _e("Voir toutes les photos","publimmo"); ?></span><?php
                                } ?>
                            </div>
                        </a><?php
                        if($nb_images > 6){
                            for ($i = 6; $i < $nb_images; $i++) {
                                $title = "<span class='modal-title'>".ucfirst($objet->data->photos[$i]->desc)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                                ?>
                                <a class="hidden hidden-sm hidden-xs" href="<?php echo str_replace("gallery","fullhd",$objet->data->photos[$i]->URL); ?>" data-title="<?php echo $title; ?>">
                                    <div class="col-md-4 image_gallery last_gallery_item" style="background-image:url(<?php echo $objet->data->photos[$i]->URL; ?>)  ">
                                        <div class="img_listings_overlay img_listings_overlay_last"></div>
                                    </div>
                                </a><?php
                            }
                        }
                    } ?>
                </div><?php
            } ?>
        </div>
    </div><?php
    if($type_gallery == "grille"){ ?>
        <div class="prop_title_zone_menu">
            <div class="container prop_title_zone_menu_container">
                <ul class="property_menu">
                    <?php getAnchorMenu($objet); ?>
                </ul>
            </div>
        </div><?php
    } ?>
    <div class="container content_wrapper">
        <div class="row">
            <div class=" col-sm-8 rightmargin full_width_prop">
                <div class="single-content listing-content"><?php
                    if(!empty($objet->data->desc)){ ?>
                        <div class="wpestate_property_description wrapper_content " id="property_description"><?php
                            if(isset($objet->data->translated)) {
                                echo '<p style="margin-bottom:10px">'.__('Le texte suivant a été traduit par Google Translate.','publimmo').'</p>';
                            }
                            echo str_replace("<br /><br /><br />","<br /><br />",nl2br($objet->data->desc)); ?>
                        </div><?php
                    }
                    if(!empty($objet->data->adresse) && !empty($objet->data->transaction) && $objet->data->transaction == "A Louer"){ ?>
                        <div class="wpestate_property_description wrapper_content " id="property_address">
                            <h4 id="property_address_title"><?php _e("Adresse", "publimmo"); ?></h4>
                            <div class="listing_detail"><?php
                                if(!empty($objet->data->npa)){
                                    echo $objet->data->adresse." / ".$objet->data->npa." ".$objet->data->localite;
                                }?>
                            </div>
                        </div><?php
                    }
                    /**
                     * Render blocks of technical datas
                     */
                    if (!empty($technicalGroups)) {
                        foreach ($technicalGroups as $group) {
                            set_query_var('fields', $group);
                            include("partials/technicalData.php");
                        }
                    }

                    if(!empty($objet->data->plans)){ ?>
                        <div class="wpestate_property_description wrapper_content " id="property_plans">
                            <h4 id="property_floor_title"><?php
                                if(count($objet->data->plans) == 1){
                                    _e("Plan", "publimmo");
                                }else{
                                    _e("Plans", "publimmo");
                                } ?>
                            </h4>
                            <ul class="nav nav-tabs floor_plans_wrapper_ul" role="tablist"><?php
                                $index_tabs_plan = 1;
                                foreach($objet->data->plans as $plan){ ?>
                                    <li role="presentation" class="<?php if($index_tabs_plan == 1){echo "active";} ?>">
                                        <a href="#floor-<?php echo $index_tabs_plan; ?>" aria-controls="floor-<?php echo $index_tabs_plan; ?>" role="tab" data-toggle="tab"><?php echo ucfirst($plan->desc ?? ''); ?></a>
                                    </li><?php
                                    $index_tabs_plan++;
                                } ?>
                            </ul>
                            <div class="tab-content floor_plans_wrapper_container"><?php
                                $index_tabs_plan = 1;
                                foreach($objet->data->plans as $plan){ ?>
                                    <div role="tabpanel" class="tab-pane <?php if($index_tabs_plan == 1){echo "active";} ?>" id="floor-<?php echo $index_tabs_plan; ?>">
                                        <div class="front_plan_row_image ">
                                            <div class="floor_image">
                                                <a href="<?php echo $plan->URL; ?>" data-title="<span class='modal-title'><?php echo ucfirst($plan->desc); ?></span>"><img class="img-responsive" src="<?php echo $plan->URL; ?>" alt="<?php echo ucfirst($plan->desc); ?>"></a>
                                            </div>
                                        </div>
                                    </div><?php
                                    $index_tabs_plan++;
                                } ?>
                            </div>
                        </div><?php
                    }
                    if(!empty($objet->data->annexes)){ ?>
                            <div class="wpestate_property_description wrapper_content " id="accordion_prop_features">
                            <h4 id="prop_annexe_title"><?php
                                if(count($objet->data->annexes) == 1){
                                    _e("Annexe", "publimmo");
                                }else{
                                    _e("Annexes", "publimmo");
                                } ?>
                            </h4>
                            <div class="row"><?php
                                foreach ($objet->data->annexes as $key => $data) {
                                    if (filter_var($data->URL, FILTER_VALIDATE_URL) !== false) {
                                        if (empty($data->desc)) {
                                            $data->desc = __('Annexe à télécharger','publimmo');
                                          } ?>
                                          <div class="listing_detail col-sm-4"><a href="<?php echo $data->URL; ?>" target="_blank" rel="noreferrer noopener"><i class="fa fa-file-pdf-o"></i><?php echo $data->desc; ?></a></div><?php
                                      }
                                  } ?>
                              </div>
                        </div><?php
                    }
                    if(!empty($objet->data->promotionTable)){
                        $costsTitle = $objet->data->transaction == "A Louer"
                            ? __('Loyer mensuel','publimmo')
                            : __('Prix de vente','publimmo');
                        ?>
                        <div class="wpestate_property_description wrapper_content">
                            <h4 id="prop_promotion_table_title">
                                <span class="hidden-xs"><?php _e("Liste des lots de cette promotion","publimmo"); ?></span><span class="hidden-not-xs"><?php _e("Liste des lots","publimmo"); ?></span>
                            </h4>
                            <div class="promo-table-resp">
                                <table id="features"><?php
                                    echo
                                    '<tr>'.
                                    '<th>'.__('Lot','publimmo').'</th>'.
                                    '<th>'.__('Étage','publimmo').'</th>'.
                                    '<th>'.__('Pièces','publimmo').'</th>'.
                                    '<th><span class="hidden-xs">'.__('Surface','publimmo').'</span><span class="hidden-not-xs"> m2</span></th>'.
                                    '<th><span class="hidden-xs">'.$costsTitle.'</span><span class="hidden-not-xs"> CHF</span></th>'.
                                    '<th>'.__('Disponibilité','publimmo').'</th>'.
                                    '</tr>';
                                    foreach($objet->data->promotionTable as $data){
                                          switch($data->disponibiliteCode) {
                                            case 1: //Réservé
                                            case 3: //Option
                                            $opacity = ' style="opacity:0.65" ';
                                            break;
                                            case 2: //Vendu
                                            $opacity = ' style="opacity:0.3" ';
                                            break;
                                            case 1: //Dispo
                                            default:
                                            $opacity = ' ';
                                          }
                                          $onClick = ' ';
                                          if($data->disponibiliteCode != 2) {
                                              $linkedObject = new Objet(array('object_data' => (object) array('id' => $data->id, 'type' => $data->type, 'typeCode' => $data->typeCode, 'localite' => $objet->data->localite, 'transaction' => $objet->data->transaction, 'inPromotionTable' => true)));
                                              $onClick = ' class="objet_promo_link" onclick="document.location=\''.$linkedObject->getUrl().'\'"';
                                          }
                                          echo
                                        '<tr'.$opacity.$onClick.' class="td-lot">'.
                                        '<td class="td-type"><span class="hidden-xs">'.((isset($data->type))?$data->type:'').' - </span>'.((isset($data->lot))?$data->lot:'').'</td>'.
                                        '<td class="td-etage">'.((isset($data->etage))?$data->etage:'').'</td>'.
                                        '<td class="td-pieces">'.((isset($data->pieces))?$data->pieces.'<span class="hidden-xs"> '.__('pces','publimmo'):'').'</span></td>'.
                                        '<td class="td-surface">'.((isset($data->surface))?$data->surface.'<span class="hidden-xs"> m2</span>':'').'</td>'.
                                        '<td class="td-prix"><span class="hidden-xs">'.((isset($data->prix))?'CHF </span>'.$data->prix:'').'</td>'.
                                        '<td class="td-dispo">'.((isset($data->disponibilite))?$data->disponibilite:'').'</td>'.
                                        '</tr>';
                                    } ?>
                                </table>
                            </div>
                        </div><?php
                    }
                    if(!empty($objet->data->pano360)){
                        add_action('wp_footer', function() {
                            echo '<script src="https://cdnjs.cloudflare.com/ajax/libs/three.js/91/three.min.js"></script>';
                        }, 999);
                        ?>
                        <div class="wpestate_property_description wrapper_content">
                            <h4 id="prop_pano360_title"><?php
                                if(count($objet->data->pano360) == 1){
                                    _e("Panoramas 360°", "publimmo");
                                }else{
                                    _e("Panoramas 360°", "publimmo");
                                } ?>
                            </h4><?php
                            $i = 0;
                            foreach($objet->data->pano360 as $pano360){
                                if($i == 0){
                                    $urlFirstPano = $pano360->URL;
                                }
                                if($i % 3 == 0){
                                    if($i >= 3){
                                        echo '<div class="row hidden">';
                                    }else{
                                        echo '<div class="row">';
                                    }
                                } ?>
                                <div class="col-sm-4">
                                    <a id="pano-<?php echo $i; ?>" class="popup-with-pano d-block" href="<?php echo get_template_directory_uri().'/pano.php?pano='.$pano360->URL; ?>">
                                        <img src="<?php echo str_replace('small','gallery-cropped',$pano360->thumb); ?>" class="img-responsive" alt="<?php echo $objet->data->titre; ?>" width="960" height="640" />
                                        <div class="pano-btn"></div>
                                    </a>
                                </div><?php
                                if($i % 3 == 2){
                                    echo '</div>';
                                }
                                $i++;
                            }
                            if($i % 3 != 0){
                                echo '</div>';
                            }
                            if(count($objet->data->pano360) > 3){ ?>
                                <div class="more-pano"><i class="circle-plus fa fa-plus" aria-hidden="true"></i></div><?php
                            } ?>
                        </div><?php
                    }

                    ?>
                    <div class="text-center hidden-xs">
                        <a class="wpresidence_button wpresidence_button_bottom" href="#demande-de-dossier"><?php _e('Demande de dossier','publimmo'); ?></a>
                    </div>
                </div>
            </div>
            <div class="col-xs-12 col-sm-4 widget-area-sidebar" id="primary">
                <?php
                do_action('begin_object_page_aside', $objet);

                if(!empty($objet->data->virtualVisitUrl)){ ?>
                    <div class="widget-container">
                        <h3 class="widget-title-sidebar"><?php _e("Visite 360°","publimmo"); ?></h3>
                        <div class="sidebar_wrap"><?php
                            $title = "<span class='modal-title'>".ucfirst($objet->data->titre)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                            ?>
                            <a href="<?php echo $objet->data->virtualVisitUrl; ?>" class="popup_iframe d-block" data-title="<?php echo $title; ?>" id="the-video-youtube">
                                <div class="pano-btn"></div>
                                <img class="img-responsive" src="<?php echo str_replace('gallery','gallery-cropped',$objet->data->photos[0]->URL); ?>" alt="">
                              </a>
                        </div>
                    </div><?php
                }
                if(!empty($objet->data->movieUrl)){ ?>
                    <div class="widget-container">
                          <h3 class="widget-title-sidebar"><?php _e("Vidéo","publimmo"); ?></h3>
                        <div class="sidebar_wrap"><?php
                            $title = "<span class='modal-title'>".ucfirst($objet->data->titre)."</span><span class='btn-modal wpresidence_button agent_submit_class'>".__('Demande de dossier','publimmo')."</span>";
                            ?>
                            <a href="<?php echo $objet->data->movieUrl; ?>" class="popup_iframe d-block" data-title="<?php echo $title; ?>">
                                <div class="play-btn"></div>
                                <img class="img-responsive" src="<?php echo str_replace('gallery','gallery-cropped',$objet->data->photos[0]->URL); ?>" alt="">
                              </a>
                        </div>
                    </div><?php
                } ?>
                <div class="widget-container">
                    <h3 class="widget-title-sidebar"><?php _e("Contact","publimmo"); ?></h3>
                    <div class="contact_sidebar_wrap"><?php
                        if (get_option('always_hide_contact_name', 'non') !== 'oui') {
                            if(!empty($objet->data->contact->name)){
                                ?><div class="title_agent_slider"><?php echo $objet->data->contact->name; ?></div><?php
                            }

                            // do we want to show the contact name instead of the network name ?
                            if ($objet->isFromNetwork() && get_option('show_contact_name') === 'oui') {
                                echo '<div class="title_agent_slider">'.$objet->data->contact->courtierPrincipal.'</div>';
                            }
                        }
                        ?>
                        <p class="widget_contact_addr"><?php echo $objet->data->contact->company; ?></p>
                        <p class="widget_contact_addr"><?php echo $objet->data->contact->address; ?></p>
                        <p class="widget_contact_addr"><?php echo $objet->data->contact->zip; ?> <?php echo $objet->data->contact->city; ?></p><?php
                        if (!empty($objet->data->contact->courtierTel)) {
                              echo '<p class="widget_contact_phone">'.__("Tél. ","publimmo").$objet->data->contact->courtierTel.'</p>';
                        } else if (!empty($objet->data->contact->tel)) {
                              echo '<p class="widget_contact_phone">'.__("Tél. ","publimmo").$objet->data->contact->tel.'</p>';
                        }
                        if (!empty($objet->data->contact->courtierMob)) {
                              echo '<p class="widget_contact_phone">'.__("Mob. ","publimmo").$objet->data->contact->courtierMob.'</p>';
                        } else if (!empty($objet->data->contact->mob)) {
                              echo '<p class="widget_contact_phone">'.__("Mob. ","publimmo").$objet->data->contact->mob.'</p>';
                        }
                        echo '<p class="widget_contact_phone"><a href="#demande-de-dossier"><i class="fa fa-envelope-o"></i> '.__('Email', 'publimmo').'</a></p>';
                        ?>
                    </div>
                </div>
                <?php
                if (!empty($objet->data->plaquetteUrl)) { ?>
                    <a class="wpresidence_button btn-icon" style="padding:8px 15px 8px 8px;margin: 0 0 30px;width:100%" target="_blank" rel="noreferrer noopener" href="<?= $objet->data->plaquetteUrl ?>">
                        <div style="margin-right:3px">
                            <?php include THEME_PATH.'/images/picto_plaquettepdf.svg'; ?>
                        </div>
                        <span><?= __('Télécharger la plaquette PDF', 'publimmo') ?></span>
                    </a>
                    <?php
                }

                if (!empty($objet->data->locationSaisonniereUrl)) { ?>
                    <a class="wpresidence_button" style="margin: 0 0 30px;width:100%" target="_blank" rel="noreferrer noopener" href="<?= $objet->data->locationSaisonniereUrl ?>">
                        <?= apply_filters('string_for_location_saisonniere', __('Réservation en ligne', 'publimmo')) ?>
                    </a>
                    <?php
                }

                /**
                 * Formulaire de demande de dossiers
                 */
                ?>
                <div class="widget-container" id="demande-de-dossier">
                    <h3 class="widget-title-sidebar"><?php _e("Demande de dossier ou de renseignements","publimmo"); ?></h3>
                    <div class="contact_sidebar_wrap"><?php
                        echo '<form class="form-publimmo">';
                        include('forms/form.php');
                        echo
                          '<input type="hidden" name="form" value="demande"/>'.
                          '<input type="hidden" name="siteurl" value="'.home_url().'"/>'.
                          '<input type="hidden" name="lang" value="'.ICL_LANGUAGE_CODE.'"/>'.
                          '<input type="hidden" name="reference" value="'.$objet->data->id.'"/>'.
                          '<input type="hidden" name="prix" value="'.((isset($objet->data->prix))?$objet->data->prix:__("Prix sur demande", "publimmo")).'"/>'.
                          '<input type="hidden" name="objet" value="'.$objet->data->titre.' - '.$objet->data->soustitre.'"/>'.
                          '<input type="hidden" name="email_webmail" value="'.$objet->data->contact->contactWebmail.'"/>'.
                          '<input type="hidden" name="contactId" value="'.$objet->data->contact->contactId.'"/>'.
                          '</form><div id="form-msg"></div>';

                        $IDPageCGU = $tools->pagesTpl['template-cgu.php'] ?? false;
                        if ($IDPageCGU) {
                            echo '<a style="display:block;margin-top:20px;line-height:1.5;" href="'.get_permalink($IDPageCGU).'" target="_blank" rel="noopener noreferrer">'.
                                __("En continuant, j'accepte les CG (y compris la déclaration de confidentialité) du site de l'agence.",'publimmo').
                                '</a>';
                        }
                        ?>
                    </div>
                </div>
                <?php

                $url = urlencode($objectUrl);
                ?>
                <div class="widget-container widget-social-sidebar">
                     <div class="social_share_wrapper">
                        <a class="social_share share_facebook_side" href="http://www.facebook.com/sharer.php?u=<?php echo $url; ?>" target="_blank" rel="noreferrer noopener"><i class="fa fa-facebook"></i></a>
                        <a class="social_share share_twiter_side" href="http://twitter.com/home?status=<?php echo $url; ?>" target="_blank" rel="noreferrer noopener"><i class="fa fa-twitter"></i></a>
                        <a class="social_share share_linkedin_side" href="http://www.linkedin.com/shareArticle?mini=true&amp;url=<?php echo $url; ?>&amp;title=<?php echo urlencode($objet->data->titre); ?>&amp;summary=<?php echo urlencode($objet->data->desc); ?>&amp;source=<?php echo urlencode(get_option("entreprise")); ?>" target="_blank" rel="noreferrer noopener"><i class="fa fa-linkedin"></i></a>
                        <a class="social_share share_email_side" href="mailto:?subject=<?php echo $objet->data->titre; ?>&amp;body=<?php echo $url; ?>"><i class="fa fa-envelope-o"></i></a>
                    </div>
                </div>
                <?php
                do_action('end_object_page_aside', $objet);
                ?>
            </div><?php
            if (!empty($objet->data->contact->courtierTel)) {
                  $phone = $objet->data->contact->courtierTel;
            } else if (!empty($objet->data->contact->tel)) {
                  $phone = $objet->data->contact->tel;
            }
            if (!empty($objet->data->contact->courtierMob)) {
                  $phone = $objet->data->contact->courtierMob;
            } else if (!empty($objet->data->contact->mob)) {
                  $phone = $objet->data->contact->mob;
            }
            ?>
            <div class="footer-object-mobile visible-xs">
                <ul id="mobile-actions">
                    <?php
                    if($phone){ ?>
                        <li><a href="tel:<?php echo $phone; ?>" target="_blank" rel="noreferrer noopener"><i class="fa fa-phone" aria-hidden="true"></i><br><?php _e('Appeler','publimmo'); ?></a></li><?php
                    }
                    ?>
                    <li><a href="#demande-de-dossier"><i class="fa fa-envelope-o" aria-hidden="true"></i><br><?php _e('Demande de dossier','publimmo'); ?></a></li>
                </ul>
            </div>
        </div>
    </div>
</div>
</div>
<?php get_footer(); ?>
