<?php
use Classes\PublimmoPro\Types;
use Classes\PublimmoPro\Subtypes;
use Classes\PublimmoPro\ObjetsSearchEngine;
use Classes\Bwap\DBCache;

function getObjectsTypes() {
    $useSubtypes = get_option('subtypes', 'inactive') === 'active';

    $types[Types::APPARTMENT] = __("Appartements","publimmo");
    if ($useSubtypes) {
        $t = 'APPARTMENT';
        foreach (Subtypes::APPARTMENT as $identifier => $key) {
            $types[Types::APPARTMENT.'_'.$key] = __($identifier, 'publimmo');
        }
    }
    $types[Types::HOUSE] = __("Maisons, villas, fermes, chalets","publimmo");
    if ($useSubtypes) {
        foreach (Subtypes::HOUSE as $identifier => $key) {
            $types[Types::HOUSE.'_'.$key] = __($identifier, 'publimmo');
        }
    }
    $types[Types::COMMERCIAL] = __("Locaux commerciaux","publimmo");
    if ($useSubtypes) {
        foreach (Subtypes::COMMERCIAL as $identifier => $key) {
            $types[Types::COMMERCIAL.'_'.$key] = __($identifier, 'publimmo');
        }
    }
    $types[Types::BUILDING] = __("Immeubles","publimmo");
    if ($useSubtypes) {
        foreach (Subtypes::BUILDING as $identifier => $key) {
            $types[Types::BUILDING.'_'.$key] = __($identifier, 'publimmo');
        }
    }
    $types[Types::LAND] = __("Terrains","publimmo");
    if ($useSubtypes) {
        foreach (Subtypes::LAND as $identifier => $key) {
            $types[Types::LAND.'_'.$key] = __($identifier, 'publimmo');
        }
    }
    $types[Types::PARKING] = __("Place de parc, garage","publimmo");
    if ($useSubtypes) {
        foreach (Subtypes::PARKING as $identifier => $key) {
            $types[Types::PARKING.'_'.$key] = __($identifier, 'publimmo');
        }
    }

    return $types;
}

$useSubtypes = get_option('subtypes', 'inactive') === 'active';

$hasForeignersFeature = true;
if($type_dobjet_affiche_sur_la_carte == 'louer'){
    $hasForeignersFeature = false;
}

$hasSecondHomeFeature = true;
if($type_dobjet_affiche_sur_la_carte == 'louer'){
    $hasSecondHomeFeature = false;
}

$hasRedirection = $redirection == 'oui';

if ($hasRedirection) {
    $redirectTo = [
        'acheter' => get_permalink($redirection_acheter[0]->ID),
        'louer' => get_permalink($redirection_louer[0]->ID),
        'tous' => get_permalink($redirection_tous[0]->ID)
    ];

    if ($type_dobjet_affiche_sur_la_carte == "acheter") {
        $action = $redirectTo['acheter'];
    } elseif ($type_dobjet_affiche_sur_la_carte == "louer") {
        $action = $redirectTo['louer'];
    } else {
        $action = $redirectTo['tous'];
    }
} else {
    $action = get_permalink();    
}

$dist = get_option('rayon_recherche');
if (empty($dist) || !empty($dist) && !is_numeric($dist)) {
    $dist = 8;
}

if(!empty($_GET['dist'])){
    $dist = $_GET['dist'];
}
$field_search_value = "";
if(!empty($_GET['communeName'])){
    $field_search_value = $_GET['communeName'];
}
$keyWords = "";
if(!empty($_GET['ns'])){
    $keyWords = $_GET['ns'];
}
if(isset($_GET['lat']) && $_GET['lat'] == "" && $_GET['lon'] == "" && $_GET['communeName'] == "" && $type_de_fond == "carte"){
    $field_search_value = __("Selon carte", "publimmo");
}
$button_submit ='<input class="wpresidence_button quickSubmit btn-submit-lg" type="submit" id="submitForm" value="'.__("Rechercher","publimmo").'"><input class="wpresidence_button quickSubmit btn-submit-sm" id="submitForm" type="submit" value="&#xf002;">';

$displayAreaFilter = true;
$displayPropretiesTypeFilter = true;
$displayKeywordsFilter = true;

if(isset($params['display-filter-area']) && $params['display-filter-area'] == 0){
    $displayAreaFilter = false;
}

if(isset($params['display-filter-properties-type']) && $params['display-filter-properties-type'] == 0){
    $displayPropretiesTypeFilter = false;
}

if(isset($params['display-filter-keywords']) && $params['display-filter-keywords'] == 0){
    $displayKeywordsFilter = false;
}


/*
* Begin template
*/
?>
<div
    class="search_wrapper search_wr_3 wrapper_search_is_float <?php if($moteur_de_recherche_deja_deploye == "oui"){echo " search-open";} if($redirection == "oui"){echo " search-with-redirection";} ?>"
    id="search_wrapper"
    >
    <div id="search_wrapper_color"></div>
    <div class="adv-search-1" id="adv-search-1">
        <div id="search">
            <form
                action="<?= $action ?>"
                id="search-form"
                name="search-form"
                method="get"
                <?php
                if ($hasRedirection)  {
                    ?>
                    data-redirectionacheter="<?= $redirectTo['acheter'] ?>"
                    data-redirectionlouer="<?= $redirectTo['louer'] ?>"
                    data-redirectiontous="<?= $redirectTo['tous'] ?>"
                    <?php
                }
                ?>
                >

                <input type="hidden" id="idpublimmo" value="<?= get_option('publimmo_settings')['agency_id']; ?>" />
                <input type="hidden" id="lat" name="lat" value="<?= isset($_GET['lat']) ? $_GET['lat'] : '' ?>" />
                <input type="hidden" id="lon" name="lon" value="<?= isset($_GET['lon']) ? $_GET['lon'] : '' ?>" />
                <input type="hidden" id="communeID" name="commune" value="<?= isset($_GET['commune']) ? $_GET['commune'] : '' ?>" />
                <input type="hidden" id="regionID" name="region" value="<?= isset($_GET['region']) ? $_GET['region'] : '' ?>" />
                <input type="hidden" id="loc" name="loc" value="<?= isset($_GET['loc']) ? $_GET['loc'] : '' ?>" />
                <input type="hidden" id="dist" name="dist" value="<?= $dist; ?>" />
                <div id="button-container-xs">
                    <a class="adv_handler_refresh" href="<?php the_permalink(); ?>"><i class="fa fa-times"></i></a>
                    <div class="adv_handler"><i class="demo-icon icon-params"></i></div>
                </div>
                <div class="clearfix"></div>
                <?php
                if($displayAreaFilter){
                ?>
                <div class="col-sm-3">
                    <div class="clearfix">
                        <input
                            type="text"
                            placeholder="<?= __("Ville, localité, NPA ou canton", "publimmo") ?>"
                            spellcheck="false"
                            autocomplete="off"
                            value="<?= $field_search_value ?>"
                            name="communeName"
                            id="searchField"
                            class="form-control hidden-sm"
                            />
                        <input
                            type="text"
                            placeholder="<?= __("Ville, NPA ou canton", "publimmo") ?>"
                            spellcheck="false"
                            autocomplete="off"
                            value="<?= $field_search_value ?>"
                            id="searchField"
                            class="form-control visible-sm"
                            />
                    </div>
                </div>
                <?php } ?>
                <div class="col-sm-3"><?php
                    if($type_dobjet_affiche_sur_la_carte == "any"){ ?>
                        <div class="dropdown form-control" id="t">
                            <div class="filter_menu_trigger" data-toggle="dropdown" data-value="all"><?php
                                if(!empty($_GET['t']) && $transaction = $_GET['t']){
                                    switch($transaction) {
                                        case '1':
                                            _e("Acheter","publimmo");
                                            $t = 1;
                                            break;
                                        case '2':
                                            _e("Louer","publimmo");
                                             $t = 2;
                                            break;
                                        default:
                                            _e("Acheter et louer","publimmo");
                                             $t = "";
                                    }
                                }else{
                                    if($type_dobjet_affiche_sur_la_carte == "any"){
                                            _e("Acheter et louer","publimmo");
                                        $t = "";
                                    }elseif($type_dobjet_affiche_sur_la_carte == "acheter"){
                                        _e("Acheter","publimmo");
                                         $t = 1;
                                    }elseif($type_dobjet_affiche_sur_la_carte == "louer"){
                                        _e("Louer","publimmo");
                                        $t = "2";
                                    }
                                } ?>
                                <span class="caret caret_filter"></span>
                            </div>
                            <input type="hidden" name="t" value="<?= $t; ?>" />
                            <ul class="dropdown-menu filter_menu">
                                <li data-value=""><?= __("Acheter et louer","publimmo"); ?></li>
                                <li data-value="1"><?= __("Acheter","publimmo"); ?></li>
                                <li data-value="2"><?= __("Louer","publimmo"); ?></li>
                            </ul>
                        </div><?php
                    }else{ ?>
                        <div class="type_transaction"><?php
                            if($type_dobjet_affiche_sur_la_carte == "acheter"){
                                _e("Acheter","publimmo");
                                 $t = 1;
                            }elseif($type_dobjet_affiche_sur_la_carte == "louer"){
                                _e("Louer","publimmo");
                                $t = "2";
                            } ?>
                        </div><?php
                    } ?>
                    <div id="value-transaction" data-transaction="<?= $t; ?>"></div>
                </div>
                <?php if($displayPropretiesTypeFilter){ ?>
                <div class="col-sm-3">
                    <div class="dropdown form-control" id="type_1">
                        <div class="filter_menu_trigger" data-toggle="dropdown" data-value="all">
                            <?php
                            $types = getObjectsTypes();
                            $cacheTime = 3600 * 8; // 8 hours of cache

                            function reduce_types($acc, $object) {
                                if (!in_array($object->typeCode, $acc, true)) {
                                    $acc[] = $object->typeCode;
                                }
                                if (!in_array($object->typeCode.'_'.$object->sousTypeCode, $acc, true)) {
                                    $acc[] = $object->typeCode.'_'.$object->sousTypeCode;
                                }
                                return $acc;
                            }

                            $t=1;

                            switch ($t) {
                                case 1: // acheter

                                    $availableTypes = DBCache::getOrSet('available_object_types_for_sale', $cacheTime, function ($publimmoClient) {
                                        $objects = (new ObjetsSearchEngine($publimmoClient, 'acheter', true, "", "", "", "1"))->results ?? [];
                                        return array_reduce($objects, 'reduce_types', []);
                                    }, true, $publimmoClient);

                                    $types = array_filter($types, function ($type) use ($availableTypes) {
                                        return in_array($type, $availableTypes, true);
                                    }, ARRAY_FILTER_USE_KEY);
                                    break;

                                case 2: // louer
                                    $availableTypes = DBCache::getOrSet('available_object_types_for_rental', $cacheTime, function ($publimmoClient) {
                                        $objects = (new ObjetsSearchEngine($publimmoClient, 'louer', true, "", "", "", "1"))->results ?? [];
                                        return array_reduce($objects, 'reduce_types', []);
                                    }, true, $publimmoClient);

                                    $types = array_filter($types, function ($type) use ($availableTypes) {
                                        return in_array($type, $availableTypes, true);
                                    }, ARRAY_FILTER_USE_KEY);
                                    break;

                                default: // tous
                                    $availableTypes = DBCache::getOrSet('available_object_types_for_rental_and_sale', $cacheTime, function ($publimmoClient) {
                                        $objects = (new ObjetsSearchEngine($publimmoClient, 'any', true, "", "", "", "1"))->results ?? [];
                                        return array_reduce($objects, 'reduce_types', []);
                                    }, true, $publimmoClient);

                                    $types = array_filter($types, function ($type) use ($availableTypes) {
                                        return in_array($type, $availableTypes, true);
                                    }, ARRAY_FILTER_USE_KEY);
                            }
                            $type = "";
                            $label = __("Tous types de biens","publimmo");

                            if(isset($params['properties-type']) && ($params['properties-type'] >= 1 && $params['properties-type'] <= 6)){
                                $type = $params['properties-type'];
                            }
                            if(!empty($_GET['type_1'])){
                                $type = $_GET['type_1'];

                            }

                            $label = $types[$type] ?? __("Tous types de biens","publimmo");

                            echo $label;
                            ?>
                            <span class="caret caret_filter"></span>
                        </div>
                        <input type="hidden" name="type_1" value="<?= $type; ?>" />
                        <ul class="dropdown-menu filter_menu">
                            <li data-value="<?= $type ?>"><?= __("Tous types de biens","publimmo"); ?></li>
                            <?php
                            foreach ($types as $value => $label) {
                                if (strpos($value, '_') === false) {
                                    $mainType = $value;

                                    if ($useSubtypes) {
                                        $label = '<b>'.$label.'</b>';
                                    }
                                } else {
                                    $mainType = strstr($value, '_', false);
                                    $label = '<span style="padding-left: 5px">'.$label.'</span>';
                                }

                                $classes = '';

                                if (in_array($mainType, [Types::BUILDING, TYPES::LAND])) {
                                    $classes .= 'hide-if-location';
                                    if ($t == 2) {
                                        $classes .= ' hidden';
                                    }
                                }

                                echo '<li data-value="'.$value.'" class="'.$classes.'">'.$label.'</li>';
                            }
                            ?>
                        </ul>
                    </div>
                </div>
                <?php } ?>
                <div class="col-sm-3" id="button-container">
                    <?= $button_submit; ?>
                    <div class="adv_handler hidden-xs"><i class="demo-icon icon-params"></i></div>
                    <a class="adv_handler_refresh hidden-xs" href="<?php the_permalink(); ?>"><i class="fa fa-times"></i></a>
                </div>
                <div class="clearfix"></div>
                <div class="adv_search_hidden_fields" style="<?= $moteur_de_recherche_deja_deploye == 'oui' ? 'display: block;' : '' ?>">
                    <div class="col-sm-6">
                        <div style="margin: 0 -7px;">
                            <div class="col-sm-4">
                                <div class="dropdown form-control" id="pieceMin">

                                    <div class="filter_menu_trigger" data-toggle="dropdown" data-value="all">
                                        <?php
                                        if(!empty($_GET['pieceMin']) && $pieceMin = $_GET['pieceMin']){
                                            echo $pieceMin;  
                                        }else{
                                            _e("Pièces min.","publimmo");
                                        }
                                        ?>
                                        <span class="caret caret_filter"></span>
                                    </div>
                                    <input type="hidden" name="pieceMin" value="" />
                                    <ul class="dropdown-menu filter_menu">
                                        <li data-value=""><?= __("Toutes","publimmo"); ?></li>
                                        <li data-value="7"><?= __("7","publimmo"); ?></li>
                                        <li data-value="6"><?= __("6","publimmo"); ?></li>
                                        <li data-value="5"><?= __("5","publimmo"); ?></li>
                                        <li data-value="4"><?= __("4","publimmo"); ?></li>
                                        <li data-value="3"><?= __("3","publimmo"); ?></li>
                                        <li data-value="2"><?= __("2","publimmo"); ?></li>
                                        <li data-value="1"><?= __("1","publimmo"); ?></li>    
                                    </ul>
                                </div>                        
                            </div>
                            <div class="col-sm-4">
                                <div class="dropdown form-control" id="surfaceMin">
<!--                                    <div class="disabled-dropdown --><?//= get_sub_field("selection_du_budget") == "non" ? "show" : '' ?><!--"></div>-->
                                    <div class="filter_menu_trigger" data-toggle="dropdown" data-value="all">
                                        <?php
                                        if(!empty($_GET['surfaceMin']) && $surfaceMin = $_GET['surfaceMin']){
                                            echo $surfaceMin;  
                                        }else{
                                            _e("Surface min.","publimmo");
                                        }
                                        ?>
                                        <span class="caret caret_filter"></span>
                                    </div>
                                    <input type="hidden" name="surfaceMin" value="" />
                                    <ul class="dropdown-menu filter_menu">
                                        <li data-value=""><?= __("Toutes","publimmo"); ?></li>
                                        <li data-value="250"><?= __("250","publimmo"); ?></li>
                                        <li data-value="225"><?= __("225","publimmo"); ?></li>
                                        <li data-value="200"><?= __("200","publimmo"); ?></li>
                                        <li data-value="175"><?= __("175","publimmo"); ?></li>
                                        <li data-value="150"><?= __("150","publimmo"); ?></li>
                                        <li data-value="125"><?= __("125","publimmo"); ?></li>
                                        <li data-value="100"><?= __("100","publimmo"); ?></li>
                                        <li data-value="75"><?= __("75","publimmo"); ?></li>
                                        <li data-value="50"><?= __("50","publimmo"); ?></li>
                                        <li data-value="25"><?= __("25","publimmo"); ?></li>
                                    </ul>
                                </div>                        
                            </div>
                            <div class="clearfix visible-xs"></div>
                            <div class="col-sm-4">
                                <div id="searchByRef">
                                    <input type="hidden" id="homeurl" value="<?= home_url() ?>" />
                                    <input type="hidden" id="lang" value="<?= ICL_LANGUAGE_CODE ?>" />
                                    <input type="text" id="ref" placeholder="#Ref." class="form-control" />
                                    <span id="msgRef"></span>
                                </div>
                            </div>
                            <?php
                            if ($hasForeignersFeature) {
                                $foreigner_value = $_GET['foreigners'] ?? 0;
                                echo '<div class="col-sm-6">'.renderCheckbox(__('Vente aux personnes étrangères autorisée', 'publimmo'), 'foreigners').'</div>';
                            }

                            if ($hasSecondHomeFeature) {
                                $seconde_home_value = $_GET['residenceSecondaire'] ?? 0;
                                echo '<div class="col-sm-6">'.renderCheckbox(__('Vente en résidence secondaire autorisée', 'publimmo'), 'residenceSecondaire').'</div>';
                            }
                            ?>
                        </div>
                    </div>
                    <div class="col-sm-6">
                        <div class="adv_search_slider">
                            <div class="slidersContainer">
                                <div class="slider js-prix">
                                    <label><?= __('Budget','publimmo') ?>:</label>
                                    <span id="prixAmount"></span>
                                    <div id="prixSlider" data-max="10000000" data-unit="CHF"></div>
                                    <input
                                        type="hidden"
                                        value="<?= ((isset($_GET['prixMin']))?$_GET['prixMin']:'') ?>"
                                        class="min"
                                        id="prixAmountMin"
                                        name="prixMin"
                                        >
                                    <input
                                        type="hidden"
                                        value="<?= ((isset($_GET['prixMax']))?$_GET['prixMax']:'') ?>"
                                        class="max"
                                        id="prixAmountMax"
                                        name="prixMax"
                                        >
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php
                    if($displayKeywordsFilter){
                    ?>
                    <div class="col-sm-6">
                        <div class="clearfix">
                            <div class="clearfix">
                                <input
                                        type="text"
                                        placeholder="<?= __("Mots-clés", "publimmo") ?>"
                                        value="<?= $keyWords ?>"
                                        name="ns"
                                        id="ns"
                                        class="form-control hidden-sm"
                                />
                                <input
                                        type="text"
                                        placeholder="<?= __("Mots-clés", "publimmo") ?>"
                                        value="<?= $keyWords ?>"
                                        id="ns"
                                        class="form-control visible-sm"
                                />
                            </div>
                        </div>
                    </div>
                    <?php } ?>
                    <div class="col-sm-3 visible-xs" id="button-container-submit">
                        <?= $button_submit; ?>
                    </div>
                    <div class="clearfix"></div>
                </div>
            </form>
        </div>
        <div class="clearfix"></div>
    </div>
</div>
